@@ -39,10 +39,7 @@ using namespace com::centreon::agent;
  * @param io_context Shared pointer to an asio::io_context object.
  * @param logger Shared pointer to an spdlog::logger object.
  * @param first_start_expected The expected first start time point.
- * @param check_interval The interval duration for checks.
- * @param serv The service name.
- * @param cmd_name The command name.
- * @param cmd_line The command line.
+ * @param serv The service.
  * @param args The JSON arguments for configuration.
  * @param cnf Shared pointer to the engine to agent request configuration.
  * @param handler The completion handler for the check.
@@ -54,10 +51,7 @@ check_event_log::check_event_log(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
     const rapidjson::Value& args,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
@@ -65,10 +59,7 @@ check_event_log::check_event_log(
     : check(io_context,
             logger,
             first_start_expected,
-            check_interval,
             serv,
-            cmd_name,
-            cmd_line,
             cnf,
             std::move(handler),
             stat) {
@@ -84,23 +75,8 @@ check_event_log::check_event_log(
 
       _verbose = arg.get_bool("verbose", true);
 
-      // check if the field warning_count and critical_count are int or string
-      _warning_threshold.extract_range(
-          arg.get_string_or_int_as_string("warning-count", "0"));
-
-      _critical_threshold.extract_range(
-          arg.get_string_or_int_as_string("critical-count", "0"));
-
-      // the number of warning/critical will always be positive or zero
-      // if the low threshold is not set, we take the default value
-      _warning_threshold.set_default_low(0);
-      _critical_threshold.set_default_low(0);
-
-      if (!_warning_threshold.is_valid() || !_critical_threshold.is_valid()) {
-        throw std::runtime_error(
-            "check event log, invalid warning-count or critical-count range");
-      }
-
+      _warning_threshold = arg.get_unsigned("warning-count", 1);
+      _critical_threshold = arg.get_unsigned("critical-count", 1);
       _empty_output =
           arg.get_string("empty-state", "Empty or no match for this filter");
 
@@ -149,10 +125,7 @@ check_event_log::check_event_log(
  * @param io_context Shared pointer to an asio::io_context object.
  * @param logger Shared pointer to an spdlog::logger object.
  * @param first_start_expected The expected first start time point.
- * @param check_interval The interval duration for checks.
- * @param serv The service name.
- * @param cmd_name The command name.
- * @param cmd_line The command line.
+ * @param serv The service.
  * @param args The JSON arguments for configuration.
  * @param cnf Shared pointer to the engine to agent request configuration.
  * @param handler The completion handler for the check.
@@ -164,17 +137,14 @@ std::shared_ptr<check_event_log> check_event_log::load(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
     const rapidjson::Value& args,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
     const checks_statistics::pointer& stat) {
   std::shared_ptr<check_event_log> ret = std::make_shared<check_event_log>(
-      io_context, logger, first_start_expected, check_interval, serv, cmd_name,
-      cmd_line, args, cnf, std::move(handler), stat);
+      io_context, logger, first_start_expected, serv, args, cnf,
+      std::move(handler), stat);
 
   ret->_data->start();
 
@@ -338,9 +308,9 @@ e_status check_event_log::compute(
   e_status status = e_status::ok;
 
   // Determine status based on thresholds
-  if (_critical_threshold.is_triggered(data.get_nb_critical())) {
+  if (data.get_nb_critical() >= _critical_threshold) {
     status = e_status::critical;
-  } else if (_warning_threshold.is_triggered(data.get_nb_warning())) {
+  } else if (data.get_nb_warning() >= _warning_threshold) {
     status = e_status::warning;
   } else {
     if (data.get_critical().empty() && data.get_warning().empty() &&
@@ -468,8 +438,8 @@ void check_event_log::help(std::ostream& help_stream) {
 - eventlog params:
     scan-range : validity of events, can be s, second, m, minute, h, hour, d, day, w, week, default: 24h
     verbose : display all events in long plugins output format (one line per event), default: true
-    warning-count : Threshold of items number with warning status to trigger WARNING. default: "0"
-    critical-count : Threshold of items number with critical status to trigger CRITICAL. default: "0"
+    warning-count : number of warning events to trigger a warning, default: 1
+    critical-count : number of critical events to trigger a critical, default: 1
     empty-state : message to display when no event is found, default: "Empty or no match for this filter"
     output-syntax : output format when status is not ok, default: "{status}: {count} {problem_list}"
     ok-syntax : output format when status is ok, default: "{status}: Event log seems fine"
