@@ -23,7 +23,6 @@
 #include "windows_util.hh"
 
 using namespace com::centreon::agent;
-using namespace com::centreon;
 using namespace com::centreon::agent::native_check_detail;
 
 namespace com::centreon::agent::native_check_detail {
@@ -156,9 +155,9 @@ void service_enumerator::_enumerate_services(
                   query_serv_conf_buff.get());
 
           bool this_serv_auto_start =
-              serv_conf->dwStartType == SERVICE_AUTO_START ||
-              serv_conf->dwStartType == SERVICE_BOOT_START ||
-              serv_conf->dwStartType == SERVICE_SYSTEM_START;
+              (serv_conf->dwStartType &
+               (SERVICE_AUTO_START | SERVICE_BOOT_START |
+                SERVICE_SYSTEM_START)) != 0;
           if (!filter.is_allowed(this_serv_auto_start, serv->lpServiceName,
                                  serv->lpDisplayName)) {
             continue;
@@ -294,17 +293,7 @@ service_filter::service_filter(const rapidjson::Value& args) {
       std::string key = absl::AsciiStrToLower(member_iter->name.GetString());
       if (key == "start-auto") {
         const rapidjson::Value& val = member_iter->value;
-        bool str_value;
-        if (val.IsString()) {
-          if (!*val.GetString()) {  // empty => we accept services start-auto or
-                                    // not
-            if (absl::SimpleAtob(val.GetString(), &str_value)) {
-              _start_auto = str_value;
-            } else {
-              throw exceptions::msg_fmt("start-auto must be a boolean");
-            }
-          }
-        } else if (val.IsBool()) {
+        if (val.IsBool()) {
           _start_auto = val.GetBool();
         } else {
           throw exceptions::msg_fmt("start-auto must be a boolean");
@@ -457,19 +446,19 @@ bool service_filter::is_allowed(bool start_auto,
  **********************************************************************************************/
 
 /**
- * The goal of this class is to convert the status field of w_service_info
- * into check_status. It compares nothing
+ * The goal of this class is to convert the status field of w_service_info into
+ * check_status. It compares nothing
  *  */
 class w_service_info_to_status
     : public measure_to_status<e_service_metric::nb_service_metric> {
  public:
   w_service_info_to_status()
-      : measure_to_status<e_service_metric::nb_service_metric>(
-            e_status::ok,
-            0,
-            common::threshold(),
-            0,
-            false) {}
+      : measure_to_status<e_service_metric::nb_service_metric>(e_status::ok,
+                                                               0,
+                                                               0,
+                                                               0,
+                                                               false,
+                                                               false) {}
 
   void compute_status(
       const snapshot<e_service_metric::nb_service_metric>& to_test,
@@ -507,47 +496,46 @@ using w_service_to_status =
     measure_to_status<e_service_metric::nb_service_metric>;
 
 using service_to_status_constructor =
-    std::function<std::unique_ptr<w_service_to_status>(
-        const common::threshold& /*threshold*/)>;
+    std::function<std::unique_ptr<w_service_to_status>(double /*threshold*/)>;
 
 static const absl::flat_hash_map<std::string_view,
                                  service_to_status_constructor>
     _label_to_service_status = {
         {"warning-total-running",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<w_service_to_status>(
                e_status::warning, e_service_metric::running, threshold,
-               e_service_metric::nb_service_metric, false);
+               e_service_metric::nb_service_metric, false, true);
          }},
         {"critical-total-running",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<w_service_to_status>(
                e_status::critical, e_service_metric::running, threshold,
-               e_service_metric::nb_service_metric, false);
+               e_service_metric::nb_service_metric, false, true);
          }},
         {"warning-total-paused",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<w_service_to_status>(
                e_status::warning, e_service_metric::paused, threshold,
-               e_service_metric::nb_service_metric, false);
+               e_service_metric::nb_service_metric, false, false);
          }},
         {"critical-total-paused",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<w_service_to_status>(
                e_status::critical, e_service_metric::paused, threshold,
-               e_service_metric::nb_service_metric, false);
+               e_service_metric::nb_service_metric, false, false);
          }},
         {"warning-total-stopped",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<w_service_to_status>(
                e_status::warning, e_service_metric::stopped, threshold,
-               e_service_metric::nb_service_metric, false);
+               e_service_metric::nb_service_metric, false, false);
          }},
         {"critical-total-stopped",
-         [](const common::threshold& threshold) {
+         [](double threshold) {
            return std::make_unique<w_service_to_status>(
                e_status::critical, e_service_metric::stopped, threshold,
-               e_service_metric::nb_service_metric, false);
+               e_service_metric::nb_service_metric, false, false);
          }}
 
 };
@@ -566,10 +554,7 @@ check_service::check_service(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
     const rapidjson::Value& args,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
@@ -577,10 +562,7 @@ check_service::check_service(
     : native_check_base(io_context,
                         logger,
                         first_start_expected,
-                        check_interval,
                         serv,
-                        cmd_name,
-                        cmd_line,
                         args,
                         cnf,
                         std::move(handler),
@@ -606,8 +588,8 @@ check_service::check_service(
         re2::RE2 filter_typ_re(val.GetString());
         if (!filter_typ_re.ok()) {
           throw exceptions::msg_fmt(
-              "command: {} warning-state: {} is not a valid regex", cmd_name,
-              val.GetString());
+              "command: {} warning-state: {} is not a valid regex",
+              get_command_name(), val.GetString());
         } else {
           for (const auto& [label, flag] : _label_state) {
             if (RE2::FullMatch(label, filter_typ_re)) {
@@ -617,7 +599,7 @@ check_service::check_service(
         }
       } else {
         throw exceptions::msg_fmt("command: {} warning-state must be a string",
-                                  cmd_name);
+                                  get_command_name());
       }
     } else if (key == "critical-state") {
       const rapidjson::Value& val = member_iter->value;
@@ -625,8 +607,8 @@ check_service::check_service(
         re2::RE2 filter_typ_re(val.GetString());
         if (!filter_typ_re.ok()) {
           throw exceptions::msg_fmt(
-              "command: {} critical-state: {} is not a valid regex", cmd_name,
-              val.GetString());
+              "command: {} critical-state: {} is not a valid regex",
+              get_command_name(), val.GetString());
         } else {
           for (const auto& [label, flag] : _label_state) {
             if (RE2::FullMatch(label, filter_typ_re)) {
@@ -636,24 +618,16 @@ check_service::check_service(
         }
       } else {
         throw exceptions::msg_fmt("command: {} critical-state must be a string",
-                                  cmd_name);
+                                  get_command_name());
       }
     } else {
       auto threshold = _label_to_service_status.find(key);
       if (threshold != _label_to_service_status.end()) {
-        std::optional<std::string> thr_str =
-            get_string(get_command_name(), member_iter->name.GetString(),
-                       member_iter->value);
-        if (thr_str) {
-          common::threshold thr(thr_str.value());
-          if (!thr.is_valid()) {
-            SPDLOG_LOGGER_ERROR(logger, "command: {}, invalid threshold: {}",
-                                get_command_name(), thr_str.value());
-            throw exceptions::msg_fmt("command: {}, invalid threshold: {}",
-                                      get_command_name(), thr_str.value());
-          }
-          thr.set_default_low(0);
-          std::unique_ptr<w_service_to_status> to_ins = threshold->second(thr);
+        std::optional<double> val =
+            get_double(get_command_name(), member_iter->name.GetString(),
+                       member_iter->value, true);
+        if (val) {
+          std::unique_ptr<w_service_to_status> to_ins = threshold->second(*val);
           _measure_to_status.emplace(
               std::make_tuple(to_ins->get_data_index(),
                               e_service_metric::nb_service_metric,
@@ -664,7 +638,7 @@ check_service::check_service(
                  key != "filter-display" && key != "exclude-display" &&
                  key != "start-auto") {
         SPDLOG_LOGGER_ERROR(logger, "command: {}, unknown parameter: {}",
-                            cmd_name, member_iter->name);
+                            get_command_name(), member_iter->name);
       }
     }
   }
@@ -720,12 +694,12 @@ void check_service::help(std::ostream& help_stream) {
         - pausing
         - paused
     critical-state: regex to match service state that will trigger a critical
-    warning-total-running: Threshold expression applied to the count of services in the "running" state to trigger a WARNING
-    critical-total-running: Threshold expression applied to the count of services in the "running" state to trigger a CRITICAL
-    warning-total-paused: Threshold expression applied to the count of services in the "paused" state to trigger a WARNING
-    critical-total-paused: Threshold expression applied to the count of services in the "paused" state to trigger a CRITICAL
-    warning-total-stopped: Threshold expression applied to the count of services in the "stopped" state to trigger a WARNING
-    critical-total-stopped: Threshold expression applied to the count of services in the "stopped" state to trigger a CRITICAL
+    warning-total-running: running service number threshold below which the service will pass in the warning state
+    critical-total-running: running service number threshold below which the service will pass in the critical state
+    warning-total-paused: number of services in the pause state above which the service goes into the warning state
+    critical-total-paused: number of services in the pause state above which the service goes into the critical state
+    warning-total-stopped: number of services in the stop state above which the service goes into the warning state
+    critical-total-stopped: number of services in the stop state above which the service goes into the critical state
     start-auto: true: only services that start automatically will be counted
     filter-name: regex to filter service names
     exclude-name: regex to exclude service names
@@ -737,8 +711,8 @@ void check_service::help(std::ostream& help_stream) {
     "args": {
       "warning-state": "stopped",
       "critical-state": "running",
-      "warning-total-running": "20",
-      "critical-total-running": "150",
+      "warning-total-running": 20,
+      "critical-total-running": 150,
       "start-auto": true,
       "filter-name": ".*",
       "exclude-name": ".*"
