@@ -25,28 +25,30 @@ using namespace com::centreon::agent;
  * check_exec
  ******************************************************************/
 
-check_exec::check_exec(const std::shared_ptr<asio::io_context>& io_context,
-                       const std::shared_ptr<spdlog::logger>& logger,
-                       time_point first_start_expected,
-                       duration check_interval,
-                       const std::string& serv,
-                       const std::string& cmd_name,
-                       const std::string& cmd_line,
-                       const engine_to_agent_request_ptr& cnf,
-                       check::completion_handler&& handler,
-                       const checks_statistics::pointer& stat)
+check_exec::check_exec(
+    const std::shared_ptr<asio::io_context>& io_context,
+    const std::shared_ptr<spdlog::logger>& logger,
+    time_point first_start_expected,
+    const Service& serv,
+    const std::string& command_line,
+    const engine_to_agent_request_ptr& cnf,
+    check::completion_handler&& handler,
+    const checks_statistics::pointer& stat,
+    const std::shared_ptr<common::crypto::aes256>& credentials_decrypt)
     : check(io_context,
             logger,
             first_start_expected,
-            check_interval,
             serv,
-            cmd_name,
-            cmd_line,
             cnf,
             std::move(handler),
-            stat) {
+            stat),
+      _credentials_decrypt(credentials_decrypt) {
   _process_args =
-      com::centreon::common::process<false>::parse_cmd_line(cmd_line);
+      com::centreon::common::process<false>::parse_cmd_line(command_line);
+  if (_credentials_decrypt) {
+    _process_args->encrypt_args(*_credentials_decrypt);
+    _process_args->clear_unencrypted_args();
+  }
 }
 
 /**
@@ -57,11 +59,7 @@ check_exec::check_exec(const std::shared_ptr<asio::io_context>& io_context,
  * @param io_context
  * @param logger
  * @param first_start_expected start expected
- * @param check_interval check interval between two checks (not only this
- * but also others)
  * @param serv
- * @param cmd_name
- * @param cmd_line
  * @param cnf   agent configuration
  * @param handler  completion handler
  * @return std::shared_ptr<check_exec>
@@ -70,16 +68,15 @@ std::shared_ptr<check_exec> check_exec::load(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
+    const std::string& command_line,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
-    const checks_statistics::pointer& stat) {
+    const checks_statistics::pointer& stat,
+    const std::shared_ptr<common::crypto::aes256>& credentials_decrypt) {
   std::shared_ptr<check_exec> ret = std::make_shared<check_exec>(
-      io_context, logger, first_start_expected, check_interval, serv, cmd_name,
-      cmd_line, cnf, std::move(handler), stat);
+      io_context, logger, first_start_expected, serv, command_line, cnf,
+      std::move(handler), stat, credentials_decrypt);
   return ret;
 }
 
@@ -97,6 +94,10 @@ void check_exec::start_check(const duration& timeout) {
   try {
     auto proc = std::make_shared<com::centreon::common::process<false>>(
         _io_context, _logger, _process_args, true, false, nullptr);
+
+    if (_credentials_decrypt) {
+      _process_args->decrypt_args(*_credentials_decrypt);
+    }
     // we add 100ms to time out in order to let check class manage timeout
     proc->start_process(
         [me = std::static_pointer_cast<check_exec>(shared_from_this()),
@@ -107,7 +108,13 @@ void check_exec::start_check(const duration& timeout) {
         },
         timeout + std::chrono::milliseconds(100));
     _pid = proc->get_pid();
+    if (_credentials_decrypt) {
+      _process_args->clear_unencrypted_args();
+    }
   } catch (const boost::system::system_error& e) {
+    if (_credentials_decrypt) {
+      _process_args->clear_unencrypted_args();
+    }
     SPDLOG_LOGGER_ERROR(_logger, " serv {} fail to execute {}: {}",
                         get_service(), get_command_line(), e.code().message());
     asio::post(*_io_context,
@@ -150,21 +157,17 @@ void check_exec::on_completion(unsigned running_index,
   std::list<std::string> outputs;
   std::list<com::centreon::common::perfdata> perfs;
 
-  std::string short_output;
-  std::string long_output;
-  std::string perf_data;
-  // parse the output check
-  common::parse_check_output(std_out, short_output, long_output, perf_data,
-                             false, true);
-  // prepare the output without perfdata
-  outputs.push_front(short_output +
-                     (long_output.empty() ? "" : "\n" + long_output));
-
-  // parse perfdata
-  if (!perf_data.empty()) {
-    boost::trim(perf_data);
-    perfs = com::centreon::common::perfdata::parse_perfdata(
-        0, 0, perf_data.c_str(), _logger);
+  // split multi line output
+  outputs = absl::StrSplit(std_out, absl::ByAnyChar("\r\n"), absl::SkipEmpty());
+  if (!outputs.empty()) {
+    const std::string& first_line = *outputs.begin();
+    size_t pipe_pos = first_line.find('|');
+    if (pipe_pos != std::string::npos) {
+      std::string perfdatas = outputs.begin()->substr(pipe_pos + 1);
+      boost::trim(perfdatas);
+      perfs = com::centreon::common::perfdata::parse_perfdata(
+          0, 0, perfdatas.c_str(), _logger);
+    }
   }
 
   check::on_completion(running_index, exit_code, perfs, outputs);
@@ -177,10 +180,7 @@ void check_exec::on_completion(unsigned running_index,
 check_dummy::check_dummy(const std::shared_ptr<asio::io_context>& io_context,
                          const std::shared_ptr<spdlog::logger>& logger,
                          time_point first_start_expected,
-                         duration check_interval,
-                         const std::string& serv,
-                         const std::string& cmd_name,
-                         const std::string& cmd_line,
+                         const Service& serv,
                          const std::string& output,
                          const engine_to_agent_request_ptr& cnf,
                          check::completion_handler&& handler,
@@ -188,10 +188,7 @@ check_dummy::check_dummy(const std::shared_ptr<asio::io_context>& io_context,
     : check(io_context,
             logger,
             first_start_expected,
-            check_interval,
             serv,
-            cmd_name,
-            cmd_line,
             cnf,
             std::move(handler),
             stat),
@@ -204,11 +201,7 @@ check_dummy::check_dummy(const std::shared_ptr<asio::io_context>& io_context,
  * @param io_context
  * @param logger
  * @param first_start_expected start expected
- * @param check_interval check interval between two checks (not only this but
- * also others)
  * @param serv
- * @param cmd_name
- * @param cmd_line
  * @param cnf   agent configuration
  * @param handler  completion handler
  * @return std::shared_ptr<check_dummy>
@@ -217,17 +210,14 @@ std::shared_ptr<check_dummy> check_dummy::load(
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger,
     time_point first_start_expected,
-    duration check_interval,
-    const std::string& serv,
-    const std::string& cmd_name,
-    const std::string& cmd_line,
+    const Service& serv,
     const std::string& output,
     const engine_to_agent_request_ptr& cnf,
     check::completion_handler&& handler,
     const checks_statistics::pointer& stat) {
   std::shared_ptr<check_dummy> ret = std::make_shared<check_dummy>(
-      io_context, logger, first_start_expected, check_interval, serv, cmd_name,
-      cmd_line, output, cnf, std::move(handler), stat);
+      io_context, logger, first_start_expected, serv, output, cnf,
+      std::move(handler), stat);
   return ret;
 }
 
