@@ -18,7 +18,6 @@
 
 #include <gtest/gtest.h>
 #include <memory>
-#include "agent.pb.h"
 #include "check.hh"
 
 #include "check_exec.hh"
@@ -29,29 +28,34 @@ using namespace com::centreon::agent;
 #define ECHO_PATH "tests\\echo.bat"
 #define SLEEP_PATH "tests\\sleep.bat"
 #define END_OF_LINE "\r\n"
-#define ECHO_MULTILINES "tests\\echo_multilines.bat"
 #else
 #define ECHO_PATH "/bin/echo"
 #define SLEEP_PATH "/bin/sleep"
 #define END_OF_LINE "\n"
-#define ECHO_MULTILINES "tests/echo_multilines.sh"
 #endif
 
 extern std::shared_ptr<asio::io_context> g_io_context;
 
-static const std::string serv("serv");
-static const std::string cmd_name("command");
-static std::string command_line;
+class check_exec_test : public testing::Test {
+ public:
+  Service serv;
 
-TEST(check_exec_test, echo) {
-  command_line = ECHO_PATH " hello toto";
+  check_exec_test() {
+    serv.set_service_description("serv");
+    serv.set_command_name("command");
+    serv.set_command_line("my_command_line");
+  }
+};
+
+TEST_F(check_exec_test, echo) {
+  serv.set_command_line(ECHO_PATH " hello toto");
   int status;
   std::list<std::string> outputs;
   std::mutex mut;
   std::condition_variable cond;
   std::shared_ptr<check_exec> check = check_exec::load(
-      g_io_context, spdlog::default_logger(), {}, {}, serv, cmd_name,
-      command_line, engine_to_agent_request_ptr(),
+      g_io_context, spdlog::default_logger(), {}, serv, serv.command_line(),
+      engine_to_agent_request_ptr(),
       [&]([[maybe_unused]] const std::shared_ptr<com::centreon::agent::check>&
               caller,
           int statuss,
@@ -65,7 +69,7 @@ TEST(check_exec_test, echo) {
         }
         cond.notify_one();
       },
-      std::make_shared<checks_statistics>());
+      std::make_shared<checks_statistics>(), nullptr);
   check->start_check(std::chrono::seconds(1));
 
   std::unique_lock l(mut);
@@ -75,14 +79,14 @@ TEST(check_exec_test, echo) {
   ASSERT_EQ(outputs.begin()->substr(0, 10), "hello toto");
 }
 
-TEST(check_exec_test, timeout) {
-  command_line = SLEEP_PATH " 120";
+TEST_F(check_exec_test, timeout) {
+  serv.set_command_line(SLEEP_PATH " 120");
   int status;
   std::list<std::string> outputs;
   std::condition_variable cond;
   std::shared_ptr<check_exec> check = check_exec::load(
-      g_io_context, spdlog::default_logger(), {}, {}, serv, cmd_name,
-      command_line, engine_to_agent_request_ptr(),
+      g_io_context, spdlog::default_logger(), {}, serv, serv.command_line(),
+      engine_to_agent_request_ptr(),
       [&]([[maybe_unused]] const std::shared_ptr<com::centreon::agent::check>&
               caller,
           int statuss,
@@ -93,7 +97,7 @@ TEST(check_exec_test, timeout) {
         outputs = output;
         cond.notify_one();
       },
-      std::make_shared<checks_statistics>());
+      std::make_shared<checks_statistics>(), nullptr);
   check->start_check(std::chrono::seconds(1));
 
   int pid = check->get_pid();
@@ -121,15 +125,15 @@ TEST(check_exec_test, timeout) {
 #endif
 }
 
-TEST(check_exec_test, bad_command) {
-  command_line = "/usr/bad_path/turlututu titi toto";
+TEST_F(check_exec_test, bad_command) {
+  serv.set_command_line("/usr/bad_path/turlututu titi toto");
   int status;
   std::list<std::string> outputs;
   std::condition_variable cond;
   std::mutex mut;
   std::shared_ptr<check_exec> check = check_exec::load(
-      g_io_context, spdlog::default_logger(), {}, {}, serv, cmd_name,
-      command_line, engine_to_agent_request_ptr(),
+      g_io_context, spdlog::default_logger(), {}, serv, serv.command_line(),
+      engine_to_agent_request_ptr(),
       [&]([[maybe_unused]] const std::shared_ptr<com::centreon::agent::check>&
               caller,
           int statuss,
@@ -141,11 +145,11 @@ TEST(check_exec_test, bad_command) {
           status = statuss;
           outputs = output;
         }
-        SPDLOG_INFO("end of {}", command_line);
+        SPDLOG_INFO("end of {}", serv.command_line());
         std::this_thread::sleep_for(std::chrono::milliseconds(50));
         cond.notify_one();
       },
-      std::make_shared<checks_statistics>());
+      std::make_shared<checks_statistics>(), nullptr);
   check->start_check(std::chrono::seconds(1));
 
   std::unique_lock l(mut);
@@ -162,13 +166,13 @@ TEST(check_exec_test, bad_command) {
 #endif
 }
 
-TEST(check_exec_test, recurse_not_lock) {
-  command_line = ECHO_PATH " hello toto";
+TEST_F(check_exec_test, recurse_not_lock) {
+  serv.set_command_line(ECHO_PATH " hello toto");
   std::condition_variable cond;
   unsigned cpt = 0;
   std::shared_ptr<check_exec> check = check_exec::load(
-      g_io_context, spdlog::default_logger(), {}, {}, serv, cmd_name,
-      command_line, engine_to_agent_request_ptr(),
+      g_io_context, spdlog::default_logger(), {}, serv, serv.command_line(),
+      engine_to_agent_request_ptr(),
       [&](const std::shared_ptr<com::centreon::agent::check>& caller, int,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
               perfdata,
@@ -179,61 +183,10 @@ TEST(check_exec_test, recurse_not_lock) {
         } else
           cond.notify_one();
       },
-      std::make_shared<checks_statistics>());
+      std::make_shared<checks_statistics>(), nullptr);
   check->start_check(std::chrono::seconds(1));
 
   std::mutex mut;
   std::unique_lock l(mut);
   cond.wait(l);
 }
-// test if the output with multiple lines is correctly displayed
-TEST(check_exec_test, echo_perfdata) {
-  Service serv;
-  serv.set_command_line(ECHO_MULTILINES);
-
-  int status = -1;
-  std::list<std::string> outputs;
-  std::list<com::centreon::common::perfdata> perfs;
-  std::mutex mut;
-  std::condition_variable cond;
-
-  std::shared_ptr<check_exec> check = check_exec::load(
-      g_io_context, spdlog::default_logger(), {}, {},
-      serv.service_description(), cmd_name, serv.command_line(),
-      engine_to_agent_request_ptr(),
-      [&]([[maybe_unused]] const std::shared_ptr<com::centreon::agent::check>&
-              caller,
-          int statuss,
-          const std::list<com::centreon::common::perfdata>& perfdata,
-          const std::list<std::string>& output) {
-        {
-          std::lock_guard l(mut);
-          status = statuss;
-          outputs = output;
-          perfs = perfdata;
-        }
-        cond.notify_one();
-      },
-      std::make_shared<checks_statistics>());
-  check->start_check(std::chrono::seconds(1));
-
-  std::unique_lock l(mut);
-  cond.wait(l);
-
-  ASSERT_EQ(status, 0);
-  ASSERT_EQ(outputs.size(), 1);
-
-  // Normalize Windows output (strip quotes, convert CRLF → LF)
-  std::string out = *outputs.begin();
-#ifdef _WIN32
-  out.erase(std::remove(out.begin(), out.end(), '\r'), out.end());
-  if (!out.empty() && out.front() == '"')
-    out.erase(out.begin());
-  if (!out.empty() && out.back() == '"')
-    out.pop_back();
-#endif
-
-  ASSERT_EQ(out.substr(0, 58),
-            "OK - load average: 0.00\nOK - load1\nOK - load5\nOK - load15\n");
-  ASSERT_EQ(perfs.size(), 3);
-}
\ No newline at end of file
