@@ -33,6 +33,7 @@ class check_files_test : public ::testing::Test {
  protected:
  public:
   static inline std::filesystem::path root_;
+  Service serv;
   static void SetUpTestCase() {
     namespace fs = std::filesystem;
 
@@ -125,8 +126,7 @@ TEST_F(check_files_test, default_behavior) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -171,8 +171,7 @@ TEST_F(check_files_test, test_filter) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -220,8 +219,7 @@ TEST_F(check_files_test, warning_status) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -267,8 +265,7 @@ TEST_F(check_files_test, critical_status) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -311,8 +308,7 @@ TEST_F(check_files_test, version) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -416,8 +412,7 @@ TEST_F(check_files_test, regex_failures) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -472,8 +467,7 @@ TEST_F(check_files_test, pattern_matching) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -519,7 +513,6 @@ TEST_F(check_files_test, pattern_matching) {
 }
 
 // Test for dangling pointers in check_files class
-// destroying check_files does not crash
 TEST_F(check_files_test, no_dangling_pointer) {
   using namespace com::centreon::common::literals;
   std::string json_str = fmt::format(R"({{
@@ -543,8 +536,7 @@ TEST_F(check_files_test, no_dangling_pointer) {
   {
     auto checker = std::make_shared<check_files>(
         g_io_context, spdlog::default_logger(),
-        std::chrono::system_clock::now(), std::chrono::seconds(1), "serv"s,
-        "cmd_name"s, "cmd_line"s, check_args, nullptr,
+        std::chrono::system_clock::now(), serv, check_args, nullptr,
         [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
             [[maybe_unused]] int status,
             [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -556,7 +548,7 @@ TEST_F(check_files_test, no_dangling_pointer) {
         },
         std::make_shared<checks_statistics>());
 
-    checker->start_check(std::chrono::seconds(120));
+    checker->start_check(std::chrono::seconds(10));
     checker.reset();  // Reset the checker to ensure it is deleted
   }
 
@@ -599,8 +591,7 @@ TEST_F(check_files_test, two_checks_same_path) {
 
   auto checker = std::make_shared<check_files>(
       g_io_context, spdlog::default_logger(), std::chrono::system_clock::now(),
-      std::chrono::seconds(1), "serv"s, "cmd_name"s, "cmd_line"s, check_args,
-      nullptr,
+      serv, check_args, nullptr,
       [&]([[maybe_unused]] const std::shared_ptr<check>& caller,
           [[maybe_unused]] int status,
           [[maybe_unused]] const std::list<com::centreon::common::perfdata>&
@@ -624,7 +615,7 @@ TEST_F(check_files_test, two_checks_same_path) {
     wait_m.Await(absl::Condition(&is_complete));
   };
 
-  run_one_check(std::chrono::seconds(120));
+  run_one_check(std::chrono::seconds(20));
 
   // extract the numbre of line for the file.72
   auto re = re2::RE2(R"(file72\.txt\s+(\d+))");
@@ -642,10 +633,10 @@ TEST_F(check_files_test, two_checks_same_path) {
   }
   out.close();
 
-  run_one_check(std::chrono::seconds(120));
+  run_one_check(std::chrono::seconds(20));
   int new_number_lines = 0;
   RE2::PartialMatch(output, re, &new_number_lines);
 
   // check if a change of lines is detected
   ASSERT_EQ(number_lines + 20, new_number_lines);
-}
+}
\ No newline at end of file
