@@ -58,19 +58,7 @@ reporting_stream::reporting_stream(
     : io::stream("BAM-BI"),
       _ack_events(0),
       _pending_events(0),
-      _mysql(db_cfg, logger),
-      _ba_full_event_insert(logger),
-      _ba_event_update(logger),
-      _ba_duration_event_insert(logger),
-      _ba_duration_event_update(logger),
-      _kpi_full_event_insert(logger),
-      _kpi_event_link(logger),
-      _kpi_event_link_update(logger),
-      _dimension_ba_insert(logger),
-      _dimension_bv_insert(logger),
-      _dimension_ba_bv_relation_insert(logger),
-      _dimension_timeperiod_insert(logger),
-      _dimension_ba_timeperiod_insert(logger),
+      _mysql(db_cfg),
       _processing_dimensions(false),
       _logger{logger} {
   SPDLOG_LOGGER_TRACE(_logger, "BAM: reporting stream constructor");
@@ -909,7 +897,7 @@ void reporting_stream::_prepare() {
         " SET end_time=?, status=?,"
         " in_downtime=?, impact_level=?"
         " WHERE kpi_id=? AND start_time=?",
-        _mysql.get_config().get_queries_per_transaction(), _logger);
+        _mysql.get_config().get_queries_per_transaction());
   } else {
     _kpi_event_update = std::make_unique<bulk_or_multi>(
         "INSERT INTO mod_bam_reporting_kpi_events (end_time, status, "
@@ -997,7 +985,7 @@ void reporting_stream::_prepare() {
         " ?, ?, ?,"
         " ?, ?, ?,"
         " ?, ?, ?)",
-        _mysql.get_config().get_queries_per_transaction(), _logger);
+        _mysql.get_config().get_queries_per_transaction());
   } else {
     _dimension_kpi_insert = std::make_unique<bulk_or_multi>(
         "INSERT INTO mod_bam_reporting_kpi (kpi_id, kpi_name,"
@@ -1143,18 +1131,6 @@ void reporting_stream::_process_pb_ba_event(
   } else {
     // Event was not found, insert one.
     try {
-      // sometimes for unknown reason, we may still have a previous event with
-      // NULL end_time so we clean it
-      std::string clean_query = fmt::format(
-          "UPDATE mod_bam_reporting_ba_events SET end_time={0} WHERE "
-          "end_time IS NULL and ba_id={1} and start_time < {0}",
-          be.start_time(), be.ba_id());
-
-      SPDLOG_LOGGER_TRACE(_logger,
-                          "reporting_stream: clean forgotten events: '{}'",
-                          clean_query);
-      _mysql.run_query(clean_query, database::mysql_error::close_ba_events);
-
       _ba_full_event_insert.bind_value_as_i32(0, be.ba_id());
       _ba_full_event_insert.bind_value_as_i32(1, be.first_level());
       _ba_full_event_insert.bind_value_as_u64(2, be.start_time());
@@ -1187,7 +1163,7 @@ void reporting_stream::_process_pb_ba_event(
         }
         // remove older events for BA
         for (auto it = m_events.begin(); it != m_events.end();) {
-          if (it->first < be.start_time())
+          if (it->first < static_cast<time_t>(be.start_time()))
             it = m_events.erase(it);
           else
             break;
@@ -1819,6 +1795,7 @@ void reporting_stream::_dimension_dispatch(
     case io::events::data_type<io::bam,
                                bam::de_dimension_ba_timeperiod_relation>::value:
       _process_dimension_ba_timeperiod_relation(data);
+      break;
     case bam::pb_dimension_ba_timeperiod_relation::static_type():
       _process_pb_dimension_ba_timeperiod_relation(data);
       break;
