@@ -27,7 +27,6 @@
 #include "com/centreon/broker/io/events.hh"
 #include "com/centreon/broker/misc/misc.hh"
 #include "com/centreon/broker/multiplexing/muxer.hh"
-#include "com/centreon/common/defer.hh"
 #include "com/centreon/common/pool.hh"
 #include "common/log_v2/log_v2.hh"
 
@@ -216,6 +215,11 @@ void engine::start() {
 void engine::stop() {
   absl::ReleasableMutexLock lck(&_kiew_m);
 
+  if (_state == not_started) {
+    _state = stopped;
+    return;
+  }
+
   if (_state != stopped) {
     // Set writing method.
     _state = stopped;
@@ -297,7 +301,7 @@ void engine::unsubscribe_muxer(const muxer* subscriber) {
 engine::engine(const std::shared_ptr<spdlog::logger>& logger)
     : _state{not_started},
       _unprocessed_events{0u},
-      _center{stats::center::instance_ptr()},
+      _center{config::applier::state::instance().center()},
       _stats{_center->register_engine()},
       _sending_to_subscribers{false},
       _logger{logger} {
@@ -373,10 +377,6 @@ bool engine::_send_to_subscribers(send_to_mux_callback_type&& callback) {
   // is _send_to_subscriber working? (_sending_to_subscribers=false)
   bool expected = false;
   if (!_sending_to_subscribers.compare_exchange_strong(expected, true)) {
-    // sending  => we will try later
-    common::defer(com::centreon::common::pool::io_context_ptr(),
-                  std::chrono::milliseconds(100),
-                  [me = _instance]() { me->_send_to_subscribers(nullptr); });
     return false;
   }
   // Now we continue and _sending_to_subscribers is true.
@@ -451,31 +451,3 @@ void engine::clear() {
   absl::MutexLock lck(&_kiew_m);
   _kiew.clear();
 }
-
-/**
- * @brief Get a muxer by name. This function returns a shared_ptr to the
- * muxer if it is running. If the muxer is not running or it doesn't exist, it
- * returns a nullptr.
- *
- * @param name Name of the muxer to get.
- *
- * @return A shared_ptr to the muxer if it is running, nullptr otherwise.
- */
-std::shared_ptr<muxer> engine::get_muxer(const std::string& name) {
-  absl::MutexLock lck(&_running_muxers_m);
-  absl::erase_if(_running_muxers,
-                 [](const std::pair<std::string, std::weak_ptr<muxer>>& p) {
-                   return p.second.expired();
-                 });
-  auto exist = _running_muxers.find(name);
-  if (exist != _running_muxers.end()) {
-    return exist->second.lock();
-  }
-  return {};
-}
-
-void engine::set_muxer(const std::string& name,
-                       const std::shared_ptr<muxer>& muxer) {
-  absl::MutexLock lck(&_running_muxers_m);
-  _running_muxers[name] = muxer;
-}
