@@ -17,7 +17,6 @@
  */
 
 #include "com/centreon/broker/sql/mysql_multi_insert.hh"
-#include <spdlog/logger.h>
 
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::database;
@@ -87,10 +86,9 @@ bulk_or_multi::bulk_or_multi(
     mysql& connexion,
     const std::string& request,
     unsigned bulk_row,
-    const std::shared_ptr<spdlog::logger>& logger,
     const std::chrono::system_clock::duration execute_delay_ready,
     unsigned row_count_ready)
-    : _bulk_stmt(std::make_unique<mysql_bulk_stmt>(request, logger)),
+    : _bulk_stmt(std::make_unique<mysql_bulk_stmt>(request)),
       _bulk_bind(_bulk_stmt->create_bind()),
       _bulk_row(bulk_row),
       _execute_delay_ready(execute_delay_ready),
@@ -185,7 +183,14 @@ std::chrono::seconds bulk_or_multi::get_oldest_waiting_event_delay() const {
  * @return true
  * @return false
  */
-bool bulk_or_multi::ready() {
+bool bulk_or_multi::ready() const {
   return get_oldest_waiting_event_delay() >= _execute_delay_ready ||
          _row_count >= _row_count_ready;
 }
+
+/**
+ * @brief force the bulk_or_multi to be ready
+ */
+void bulk_or_multi::force_ready() {
+  _first_row_add_time = std::chrono::system_clock::time_point::max();
+}
