@@ -1,5 +1,5 @@
 /**
- * Copyright 2020-2023 Centreon (https://www.centreon.com/)
+ * Copyright 2020-2024 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,20 +18,25 @@
  */
 
 #include "com/centreon/broker/broker_impl.hh"
+#include <google/protobuf/util/time_util.h>
+#include <grpcpp/support/status.h>
 
 #include "com/centreon/broker/config/applier/endpoint.hh"
 #include "com/centreon/broker/config/applier/state.hh"
 #include "com/centreon/broker/multiplexing/publisher.hh"
-#include "com/centreon/broker/stats/center.hh"
 #include "com/centreon/broker/stats/helper.hh"
 #include "com/centreon/broker/version.hh"
 #include "com/centreon/common/process_stat.hh"
+#include "common/crypto/aes256.hh"
 #include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::version;
+using com::centreon::common::crypto::aes256;
 using com::centreon::common::log_v2::log_v2;
 
+broker_impl::broker_impl(const std::string& name) : _broker_name(name) {}
+
 /**
  * @brief Return the Broker's version.
  *
@@ -196,7 +201,7 @@ grpc::Status broker_impl::GetSqlManagerStats(grpc::ServerContext* context
                                              [[maybe_unused]],
                                              const SqlConnection* request,
                                              SqlManagerStats* response) {
-  auto center = stats::center::instance_ptr();
+  auto center = config::applier::state::instance().center();
   if (!request->has_id())
     center->get_sql_manager_stats(response);
   else {
@@ -227,8 +232,8 @@ grpc::Status broker_impl::GetConflictManagerStats(
     grpc::ServerContext* context [[maybe_unused]],
     const ::google::protobuf::Empty* request [[maybe_unused]],
     ConflictManagerStats* response) {
-  auto center = stats::center::instance_ptr();
-  center->get_conflict_manager_stats(response);
+  config::applier::state::instance().center()->get_conflict_manager_stats(
+      response);
   return grpc::Status::OK;
 }
 
@@ -237,8 +242,8 @@ grpc::Status broker_impl::GetMuxerStats(grpc::ServerContext* context
                                         const GenericString* request,
                                         MuxerStats* response) {
   const std::string name = request->str_arg();
-  auto center = stats::center::instance_ptr();
-  bool status = center->muxer_stats(name, response);
+  bool status =
+      config::applier::state::instance().center()->muxer_stats(name, response);
   return status ? grpc::Status::OK
                 : grpc::Status(
                       grpc::StatusCode::NOT_FOUND,
@@ -295,8 +300,7 @@ grpc::Status broker_impl::GetProcessingStats(
     grpc::ServerContext* context [[maybe_unused]],
     const ::google::protobuf::Empty* request [[maybe_unused]],
     ::ProcessingStats* response) {
-  auto center = stats::center::instance_ptr();
-  center->get_processing_stats(response);
+  config::applier::state::instance().center()->get_processing_stats(response);
   return grpc::Status::OK;
 }
 
@@ -394,3 +398,53 @@ grpc::Status broker_impl::SetLogFlushPeriod(grpc::ServerContext* context
   }
   return grpc::Status::OK;
 }
+
+grpc::Status broker_impl::Aes256Encrypt(grpc::ServerContext* context
+                                        [[maybe_unused]],
+                                        const AesMessage* request,
+                                        GenericString* response) {
+  std::string first_key = request->app_secret();
+  std::string second_key = request->salt();
+
+  try {
+    aes256 access(first_key, second_key);
+    std::string result = access.encrypt(request->content());
+    response->set_str_arg(result);
+    return grpc::Status::OK;
+  } catch (const std::exception& e) {
+    return grpc::Status(grpc::INVALID_ARGUMENT, grpc::string(e.what()));
+  }
+}
+
+grpc::Status broker_impl::Aes256Decrypt(grpc::ServerContext* context
+                                        [[maybe_unused]],
+                                        const AesMessage* request,
+                                        GenericString* response) {
+  std::string first_key = request->app_secret();
+  std::string second_key = request->salt();
+
+  try {
+    aes256 access(first_key, second_key);
+    std::string result = access.decrypt(request->content());
+    response->set_str_arg(result);
+    return grpc::Status::OK;
+  } catch (const std::exception& e) {
+    return grpc::Status(grpc::INVALID_ARGUMENT, grpc::string(e.what()));
+  }
+}
+
+grpc::Status broker_impl::GetPeers(grpc::ServerContext* context
+                                   [[maybe_unused]],
+                                   const ::google::protobuf::Empty* request
+                                   [[maybe_unused]],
+                                   PeerList* response) {
+  for (auto& p : config::applier::state::instance().connected_peers()) {
+    auto peer = response->add_peers();
+    peer->set_id(p.poller_id);
+    peer->set_poller_name(p.poller_name);
+    peer->set_broker_name(p.broker_name);
+    peer->mutable_connected_since()->set_seconds(p.connected_since);
+    peer->set_type(p.peer_type);
+  }
+  return grpc::Status::OK;
+}
