@@ -1,25 +1,24 @@
-/*
-** Copyright 2015-2017 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2015-2017 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/broker/http_tsdb/line_protocol_query.hh"
 #include "com/centreon/broker/cache/global_cache.hh"
 #include "com/centreon/broker/http_tsdb/internal.hh"
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/misc/string.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 
@@ -362,7 +361,7 @@ void line_protocol_query::_throw_on_invalid(data_type macro_type) {
  */
 template <typename T, typename U, T(U::*member)>
 void line_protocol_query::_get_member(io::data const& d,
-                                      unsigned& string_index,
+                                      unsigned& string_index [[maybe_unused]],
                                       std::ostream& is) const {
   is << static_cast<U const&>(d).*member;
 }
@@ -387,7 +386,8 @@ void line_protocol_query::_get_string(io::data const& d,
  *  @param[in] is  The stream.
  */
 void line_protocol_query::_get_dollar_sign(io::data const& d,
-                                           unsigned& string_index,
+                                           unsigned& string_index
+                                           [[maybe_unused]],
                                            std::ostream& is) const {
   (void)d;
   is << "$";
@@ -429,7 +429,7 @@ uint64_t line_protocol_query::_get_index_id(io::data const& d) const {
  *  @param[out] is  The stream.
  */
 void line_protocol_query::_get_index_id(io::data const& d,
-                                        unsigned& string_index,
+                                        unsigned& string_index [[maybe_unused]],
                                         std::ostream& is) const {
   cache::global_cache::lock l;
   is << _get_index_id(d);
@@ -442,7 +442,7 @@ void line_protocol_query::_get_index_id(io::data const& d,
  *  @param is     The stream.
  */
 void line_protocol_query::_get_host(io::data const& d,
-                                    unsigned& string_index,
+                                    unsigned& string_index [[maybe_unused]],
                                     std::ostream& is) const {
   uint64_t host_id =
       d.type() == storage::pb_metric::static_type()
@@ -477,7 +477,7 @@ uint64_t line_protocol_query::_get_host_id(io::data const& d) const {
  *  @param is     The stream.
  */
 void line_protocol_query::_get_host_id(io::data const& d,
-                                       unsigned& string_index,
+                                       unsigned& string_index [[maybe_unused]],
                                        std::ostream& is) const {
   is << _get_host_id(d);
 }
@@ -489,7 +489,7 @@ void line_protocol_query::_get_host_id(io::data const& d,
  *  @param is     The stream.
  */
 void line_protocol_query::_get_service(io::data const& d,
-                                       unsigned& string_index,
+                                       unsigned& string_index [[maybe_unused]],
                                        std::ostream& is) const {
   cache::host_serv_pair host_serv = _get_service_id(d);
   cache::global_cache::lock l;
@@ -524,7 +524,8 @@ cache::host_serv_pair line_protocol_query::_get_service_id(
  *  @param is     The stream.
  */
 void line_protocol_query::_get_service_id(io::data const& d,
-                                          unsigned& string_index,
+                                          unsigned& string_index
+                                          [[maybe_unused]],
                                           std::ostream& is) const {
   is << _get_service_id(d).second;
 }
@@ -536,7 +537,7 @@ void line_protocol_query::_get_service_id(io::data const& d,
  *  @param is     The stream.
  */
 void line_protocol_query::_get_instance(io::data const& d,
-                                        unsigned& string_index,
+                                        unsigned& string_index [[maybe_unused]],
                                         std::ostream& is) const {
   cache::global_cache::lock l;
   const cache::string* instance_name =
@@ -554,7 +555,8 @@ void line_protocol_query::_get_instance(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_host_group(io::data const& d,
-                                          unsigned& string_index,
+                                          unsigned& string_index
+                                          [[maybe_unused]],
                                           std::ostream& is) const {
   cache::global_cache::lock l;
   cache::global_cache::instance_ptr()->append_host_group(_get_host_id(d), is);
@@ -568,7 +570,8 @@ void line_protocol_query::_get_host_group(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_service_group(io::data const& d,
-                                             unsigned& string_index,
+                                             unsigned& string_index
+                                             [[maybe_unused]],
                                              std::ostream& is) const {
   cache::host_serv_pair host_serv = _get_service_id(d);
   cache::global_cache::lock l;
@@ -584,7 +587,7 @@ void line_protocol_query::_get_service_group(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_min(io::data const& d,
-                                   unsigned& string_index,
+                                   unsigned& string_index [[maybe_unused]],
                                    std::ostream& is) const {
   cache::global_cache::lock l;
   const cache::metric_info* infos = _get_metric_info(d);
@@ -601,7 +604,7 @@ void line_protocol_query::_get_min(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_max(io::data const& d,
-                                   unsigned& string_index,
+                                   unsigned& string_index [[maybe_unused]],
                                    std::ostream& is) const {
   cache::global_cache::lock l;
   const cache::metric_info* infos = _get_metric_info(d);
@@ -618,7 +621,8 @@ void line_protocol_query::_get_max(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_resource_id(io::data const& d,
-                                           unsigned& string_index,
+                                           unsigned& string_index
+                                           [[maybe_unused]],
                                            std::ostream& is) const {
   cache::host_serv_pair host_serv = _get_service_id(d);
   cache::global_cache::lock l;
@@ -723,7 +727,8 @@ void line_protocol_query::_get_tag_serv_name(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_metric_name(io::data const& d,
-                                           unsigned& string_index,
+                                           unsigned& string_index
+                                           [[maybe_unused]],
                                            std::ostream& is) const {
   is << static_cast<storage::pb_metric const&>(d).obj().name();
 }
@@ -735,7 +740,8 @@ void line_protocol_query::_get_metric_name(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_metric_id(io::data const& d,
-                                         unsigned& string_index,
+                                         unsigned& string_index
+                                         [[maybe_unused]],
                                          std::ostream& is) const {
   is << static_cast<storage::pb_metric const&>(d).obj().metric_id();
 }
@@ -747,7 +753,8 @@ void line_protocol_query::_get_metric_id(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_metric_value(io::data const& d,
-                                            unsigned& string_index,
+                                            unsigned& string_index
+                                            [[maybe_unused]],
                                             std::ostream& is) const {
   is << static_cast<storage::pb_metric const&>(d).obj().value();
 }
@@ -759,7 +766,8 @@ void line_protocol_query::_get_metric_value(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_metric_time(io::data const& d,
-                                           unsigned& string_index,
+                                           unsigned& string_index
+                                           [[maybe_unused]],
                                            std::ostream& is) const {
   is << static_cast<storage::pb_metric const&>(d).obj().time();
 }
@@ -771,7 +779,8 @@ void line_protocol_query::_get_metric_time(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_status_state(io::data const& d,
-                                            unsigned& string_index,
+                                            unsigned& string_index
+                                            [[maybe_unused]],
                                             std::ostream& is) const {
   is << static_cast<storage::pb_status const&>(d).obj().state();
 }
@@ -783,7 +792,8 @@ void line_protocol_query::_get_status_state(io::data const& d,
  * @param is
  */
 void line_protocol_query::_get_status_time(io::data const& d,
-                                           unsigned& string_index,
+                                           unsigned& string_index
+                                           [[maybe_unused]],
                                            std::ostream& is) const {
   is << static_cast<storage::pb_status const&>(d).obj().time();
 }
