@@ -1,5 +1,5 @@
 /**
- * Copyright 2018-2025 Centreon
+ * Copyright 2018 Centreon
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -172,7 +172,7 @@ static int l_broker_cache_get_hostgroup_name(lua_State* L) {
 
   try {
     std::string const& hg{cache->get_host_group_name(id)};
-    lua_pushlstring(L, hg.c_str(), hg.length());
+    lua_pushstring(L, hg.c_str());
   } catch (std::exception const& e) {
     (void)e;
     lua_pushnil(L);
@@ -194,8 +194,8 @@ static int l_broker_cache_get_hostgroup_alias(lua_State* L) {
   int id(luaL_checkinteger(L, 2));
 
   try {
-    const std::string& hg{cache->get_host_group_alias(id)};
-    lua_pushlstring(L, hg.c_str(), hg.length());
+    std::string const& hg{cache->get_host_group_alias(id)};
+    lua_pushstring(L, hg.c_str());
   } catch (std::exception const& e) {
     (void)e;
     lua_pushnil(L);
@@ -467,26 +467,27 @@ static int l_broker_cache_get_servicegroups(lua_State* L) {
 
   auto const& members = cache->get_service_group_members();
 
-  auto found =
-      members.get<1>().lower_bound(std::make_tuple(host_id, service_id, 0));
+  auto first(members.lower_bound(std::make_tuple(host_id, service_id, 0)));
+  auto second(members.upper_bound(std::make_tuple(host_id, service_id + 1, 0)));
 
   lua_newtable(L);
 
-  int i = 1;
-  for (; found != members.get<1>().end() &&
-         (*found)->obj().host_id() == host_id &&
-         (*found)->obj().service_id() == service_id;
-       ++found) {
-    lua_createtable(L, 0, 2);
-    const ServiceGroupMember& sgm = (*found)->obj();
+  if (first != members.end()) {
+    int i{1};
+    for (auto it(first), end(second); it != end; ++it) {
+      lua_createtable(L, 0, 2);
+      const ServiceGroupMember& sgm =
+          std::static_pointer_cast<neb::pb_service_group_member>(it->second)
+              ->obj();
 
-    lua_pushinteger(L, sgm.servicegroup_id());
-    lua_setfield(L, -2, "group_id");
+      lua_pushinteger(L, sgm.servicegroup_id());
+      lua_setfield(L, -2, "group_id");
 
-    lua_pushstring(L, sgm.name().c_str());
-    lua_setfield(L, -2, "group_name");
-    lua_rawseti(L, -2, i);
-    ++i;
+      lua_pushstring(L, sgm.name().c_str());
+      lua_setfield(L, -2, "group_name");
+      lua_rawseti(L, -2, i);
+      ++i;
+    }
   }
   return 1;
 }
@@ -495,7 +496,7 @@ static int l_broker_cache_get_servicegroups(lua_State* L) {
  *  The get_hostgroups() method available in the Lua interpreter
  *  It returns an array of host groups from a host id.
  *
- *  @param L The Lua interpreter (host_id)
+ *  @param L The Lua interpreter
  *
  *  @return 1
  */
@@ -504,25 +505,29 @@ static int l_broker_cache_get_hostgroups(lua_State* L) {
       *static_cast<macro_cache**>(luaL_checkudata(L, 1, "lua_broker_cache"))};
   uint64_t id{static_cast<uint64_t>(luaL_checkinteger(L, 2))};
 
-  const auto& members = cache->get_host_group_members();
+  auto const& members = cache->get_host_group_members();
 
-  auto found = members.get<1>().lower_bound(std::make_pair(id, 0));
+  auto const first = members.lower_bound({id, 0});
+  auto const second = members.upper_bound({id + 1, 0});
 
-  int i = 1;
   lua_newtable(L);
-  for (; found != members.get<1>().end() && (*found)->obj().host_id() == id;
-       ++found) {
-    lua_createtable(L, 0, 2);
-    const HostGroupMember& hgm = (*found)->obj();
-    lua_pushinteger(L, hgm.hostgroup_id());
-    lua_setfield(L, -2, "group_id");
+  if (first != members.end()) {
+    int i = 1;
+    for (auto it(first); it != second; ++it) {
+      lua_createtable(L, 0, 2);
+      std::shared_ptr<io::data> evt = it->second;
+      const HostGroupMember& hgm =
+          std::static_pointer_cast<neb::pb_host_group_member>(it->second)
+              ->obj();
+      lua_pushinteger(L, hgm.hostgroup_id());
+      lua_setfield(L, -2, "group_id");
 
-    lua_pushstring(L, hgm.name().c_str());
-    lua_setfield(L, -2, "group_name");
-    lua_rawseti(L, -2, i);
-    ++i;
+      lua_pushstring(L, hgm.name().c_str());
+      lua_setfield(L, -2, "group_name");
+      lua_rawseti(L, -2, i);
+      ++i;
+    }
   }
-
   return 1;
 }
 
