@@ -298,6 +298,17 @@ std::string const& macro_cache::get_notes(uint64_t host_id,
   }
 }
 
+/**
+ *  Get a map of the host groups members index by host_id and host_group.
+ *
+ *  @return             A std::map
+ */
+const absl::btree_map<std::pair<uint64_t, uint64_t>,
+                      std::shared_ptr<neb::pb_host_group_member>>&
+macro_cache::get_host_group_members() const {
+  return _host_group_members;
+}
+
 /**
  *  Get the name of a host group.
  *
@@ -306,14 +317,14 @@ std::string const& macro_cache::get_notes(uint64_t host_id,
  *  @return             The name of the host group.
  */
 const std::string& macro_cache::get_host_group_name(uint64_t id) const {
-  auto found = _host_groups.lower_bound(std::make_pair(id, 0));
+  const auto found = _host_groups.find(id);
 
-  if (found == _host_groups.end() || found->first.first != id) {
-    SPDLOG_LOGGER_ERROR(_cache->logger(),
-                        "lua: could not find information on host group {}", id);
+  if (found == _host_groups.end()) {
+    _cache->logger()->error("lua: could not find information on host group {}",
+                            id);
     throw msg_fmt("lua: could not find information on host group {}", id);
   }
-  return found->second->obj().name();
+  return found->second.first->obj().name();
 }
 
 /**
@@ -324,15 +335,15 @@ const std::string& macro_cache::get_host_group_name(uint64_t id) const {
  *  @return             The alias of the host group.
  */
 const std::string& macro_cache::get_host_group_alias(uint64_t id) const {
-  const auto found = _host_groups.lower_bound(std::make_pair(id, 0));
+  const auto found = _host_groups.find(id);
 
-  if (found == _host_groups.end() || found->first.first != id) {
-    SPDLOG_LOGGER_ERROR(_cache->logger(),
-                        "lua: could not find information on host group {}", id);
+  if (found == _host_groups.end()) {
+    _cache->logger()->error("lua: could not find information on host group {}",
+                            id);
     throw msg_fmt("lua: could not find information on host group {}", id);
   }
 
-  return found->second->obj().alias();
+  return found->second.first->obj().alias();
 }
 
 /**
@@ -353,6 +364,20 @@ std::string const& macro_cache::get_service_description(
   return found->second->obj().description();
 }
 
+/**
+ *  Service group members accessor
+ *
+ *  @param[in] host_id  The id of the host.
+ *  @param[in] service_id  The id of the service.
+ *
+ *  @return   A map indexed by host_id/service_id/group_id.
+ */
+absl::btree_map<std::tuple<uint64_t, uint64_t, uint64_t>,
+                std::shared_ptr<neb::pb_service_group_member>> const&
+macro_cache::get_service_group_members() const {
+  return _service_group_members;
+}
+
 /**
  *  Get the name of a service group.
  *
@@ -361,15 +386,14 @@ std::string const& macro_cache::get_service_description(
  *  @return            The name of the service group.
  */
 std::string const& macro_cache::get_service_group_name(uint64_t id) const {
-  auto found = _service_groups.lower_bound(std::make_pair(id, 0));
+  auto found = _service_groups.find(id);
 
-  if (found == _service_groups.end() || found->first.first != id) {
-    SPDLOG_LOGGER_ERROR(_cache->logger(),
-                        "lua: could not find information on service group {}",
-                        id);
+  if (found == _service_groups.end()) {
+    _cache->logger()->error(
+        "lua: could not find information on service group {}", id);
     throw msg_fmt("lua: could not find information on service group {}", id);
   }
-  return found->second->obj().name();
+  return found->second.first->obj().name();
 }
 
 /**
@@ -720,18 +744,35 @@ void macro_cache::_process_pb_host_group(
     const std::shared_ptr<io::data>& data) {
   auto pb_hg = std::static_pointer_cast<neb::pb_host_group>(data);
   const HostGroup& hg = pb_hg->obj();
-  SPDLOG_LOGGER_DEBUG(
-      _cache->logger(),
-      "lua: processing pb host group '{}' of id {} for poller {}, enabled {}",
-      hg.name(), hg.hostgroup_id(), hg.poller_id(), hg.enabled());
-
-  auto key = std::make_pair(hg.hostgroup_id(), hg.poller_id());
-
+  SPDLOG_LOGGER_DEBUG(_cache->logger(),
+                      "lua: processing pb host group '{}' of id {}, enabled {}",
+                      hg.name(), hg.hostgroup_id(), hg.enabled());
   if (hg.enabled()) {
-    _host_groups[key] = pb_hg;
+    auto found = _host_groups.find(hg.hostgroup_id());
+    if (found != _host_groups.end()) {
+      found->second.second.insert(hg.poller_id());
+      HostGroup& current_hg =
+          std::static_pointer_cast<neb::pb_host_group>(found->second.first)
+              ->mut_obj();
+      current_hg.set_name(hg.name());
+    } else {
+      absl::flat_hash_set<uint32_t> pollers{hg.poller_id()};
+      _host_groups[hg.hostgroup_id()] =
+          std::make_pair(std::move(pb_hg), pollers);
+    }
   } else {
-    _host_groups.erase(key);
-    _host_group_members.get<0>().erase(key);
+    /* We check that no more pollers need this host group. So if the set is
+     * empty, we can also remove the host group. */
+    auto found = _host_groups.find(hg.hostgroup_id());
+    if (found != _host_groups.end()) {
+      auto f = found->second.second.find(hg.poller_id());
+      if (f != found->second.second.end()) {
+        found->second.second.erase(f);
+        if (found->second.second.empty()) {
+          _host_groups.erase(found);
+        }
+      }
+    }
   }
 }
 
@@ -747,28 +788,13 @@ void macro_cache::_process_pb_host_group_member(
   SPDLOG_LOGGER_DEBUG(
       _cache->logger(),
       "lua: processing pb host group member (group_name: '{}', group_id: {}, "
-      "host_id: {} poller_id: {}, enabled: {})",
+      "host_id: {}, enabled: {})",
       hgm_obj.name(), hgm_obj.hostgroup_id(), hgm_obj.host_id(),
-      hgm_obj.poller_id(), hgm_obj.enabled());
-
-  if (hgm_obj.enabled()) {
-    auto res_insert = _host_group_members.insert(hgm);
-    if (!res_insert.second) {
-      _host_group_members.replace(res_insert.first, hgm);
-    }
-  } else {
-    _host_group_members.get<1>().erase(
-        std::make_pair(hgm_obj.host_id(), hgm_obj.hostgroup_id()));
-
-    auto clean = std::make_pair(hgm_obj.hostgroup_id(), hgm_obj.poller_id());
-    // remainded members
-    auto remainded = _host_group_members.get<0>().find(clean);
-
-    if (remainded == _host_group_members.get<0>().end()) {
-      // no more hostgroup member for this group and this poller => erase
-      _host_groups.erase(clean);
-    }
-  }
+      hgm_obj.enabled());
+  if (hgm_obj.enabled())
+    _host_group_members[{hgm_obj.host_id(), hgm_obj.hostgroup_id()}] = hgm;
+  else
+    _host_group_members.erase({hgm_obj.host_id(), hgm_obj.hostgroup_id()});
 }
 
 /**
@@ -936,12 +962,31 @@ void macro_cache::_process_pb_service_group(
   SPDLOG_LOGGER_DEBUG(_cache->logger(),
                       "lua: processing pb service group '{}' of id {}",
                       sg.name(), sg.servicegroup_id());
-  auto key = std::make_pair(sg.servicegroup_id(), sg.poller_id());
   if (sg.enabled()) {
-    _service_groups[key] = pb_sg;
+    auto found = _service_groups.find(sg.servicegroup_id());
+    if (found != _service_groups.end()) {
+      found->second.second.insert(sg.poller_id());
+      ServiceGroup& current_sg = found->second.first->mut_obj();
+      current_sg.set_name(sg.name());
+    } else {
+      /* Here, we add the servicegroup and the first poller that needs it */
+      absl::flat_hash_set<uint32_t> pollers{sg.poller_id()};
+      _service_groups[sg.servicegroup_id()] =
+          std::make_pair(std::move(pb_sg), pollers);
+    }
   } else {
-    _service_groups.erase(key);
-    _service_group_members.get<0>().erase(key);
+    /* We check that no more pollers need this service group. So if the set is
+     * empty, we can also remove the service group. */
+    auto found = _service_groups.find(sg.servicegroup_id());
+    if (found != _service_groups.end()) {
+      auto f = found->second.second.find(sg.poller_id());
+      if (f != found->second.second.end()) {
+        found->second.second.erase(f);
+        if (found->second.second.empty()) {
+          _service_groups.erase(found);
+        }
+      }
+    }
   }
 }
 
@@ -961,24 +1006,13 @@ void macro_cache::_process_pb_service_group_member(
                       sgm_obj.name(), sgm_obj.servicegroup_id(),
                       sgm_obj.host_id(), sgm_obj.service_id(),
                       sgm_obj.enabled());
-  if (sgm_obj.enabled()) {
-    auto res_insert = _service_group_members.insert(sgm);
-    if (!res_insert.second) {
-      _service_group_members.replace(res_insert.first, sgm);
-    }
-  } else {
-    _service_group_members.get<1>().erase(std::make_tuple(
+  if (sgm_obj.enabled())
+    _service_group_members[std::make_tuple(
+        sgm_obj.host_id(), sgm_obj.service_id(), sgm_obj.servicegroup_id())] =
+        sgm;
+  else
+    _service_group_members.erase(std::make_tuple(
         sgm_obj.host_id(), sgm_obj.service_id(), sgm_obj.servicegroup_id()));
-
-    auto clean = std::make_pair(sgm_obj.servicegroup_id(), sgm_obj.poller_id());
-    // remainded members
-    auto remainded = _service_group_members.get<0>().find(clean);
-
-    if (remainded == _service_group_members.get<0>().end()) {
-      // no more service group member for this group and this poller => erase
-      _service_groups.erase(clean);
-    }
-  }
 }
 
 /**
@@ -1108,23 +1142,34 @@ void macro_cache::_save_to_disk() {
   for (auto it(_hosts.begin()), end(_hosts.end()); it != end; ++it)
     _cache->add(it->second);
 
-  for (const auto& hgrp : _host_groups) {
-    _cache->add(hgrp.second);
-  }
-  for (const auto& member : _host_group_members) {
-    _cache->add(member);
+  for (auto it = _host_groups.begin(), end = _host_groups.end(); it != end;
+       ++it) {
+    for (auto poller_id : it->second.second) {
+      it->second.first->mut_obj().set_poller_id(poller_id);
+      _cache->add(it->second.first);
+    }
   }
 
+  for (auto it(_host_group_members.begin()), end(_host_group_members.end());
+       it != end; ++it)
+    _cache->add(it->second);
+
   for (auto it(_services.begin()), end(_services.end()); it != end; ++it)
     _cache->add(it->second);
 
-  for (const auto& sgrp : _service_groups) {
-    _cache->add(sgrp.second);
-  }
-  for (const auto& member : _service_group_members) {
-    _cache->add(member);
+  for (auto it = _service_groups.begin(), end = _service_groups.end();
+       it != end; ++it) {
+    for (auto poller_id : it->second.second) {
+      it->second.first->mut_obj().set_poller_id(poller_id);
+      _cache->add(it->second.first);
+    }
   }
 
+  for (auto it = _service_group_members.begin(),
+            end = _service_group_members.end();
+       it != end; ++it)
+    _cache->add(it->second);
+
   for (auto it(_index_mappings.begin()), end(_index_mappings.end()); it != end;
        ++it)
     _cache->add(it->second);
