@@ -196,7 +196,9 @@ TEST(StoragePerfdata, DefaultCtor) {
 
 class StorageParserParsePerfdata : public testing::Test {
  public:
-  void SetUp() override { config::applier::init(0, "test_broker", 0); }
+  void SetUp() override {
+    config::applier::init(com::centreon::common::BROKER, 0, "test_broker", 0);
+  }
   void TearDown() override { config::applier::deinit(); };
 };
 
