@@ -48,8 +48,7 @@ static constexpr multiplexing::muxer_filter _tcp_forbidden_filter =
  */
 connector::connector(const tcp_config::pointer& conf)
     : io::limit_endpoint(false, _tcp_stream_filter, _tcp_forbidden_filter),
-      _conf(conf),
-      _logger(log_v2::instance().get(log_v2::TCP)) {}
+      _conf(conf) {}
 
 /**
  * @brief Connect to the remote host.
@@ -57,13 +56,15 @@ connector::connector(const tcp_config::pointer& conf)
  * @return The TCP connection object.
  */
 std::shared_ptr<io::stream> connector::open() {
+  auto logger = log_v2::instance().get(log_v2::TCP);
+
   // Launch connection process.
-  _logger->info("TCP: connecting to {}:{}", _conf->get_host(),
-                _conf->get_port());
+  logger->info("TCP: connecting to {}:{}", _conf->get_host(),
+               _conf->get_port());
   try {
     return limit_endpoint::open();
   } catch (const std::exception& e) {
-    _logger->debug(
+    logger->debug(
         "Unable to establish the connection to {}:{} (attempt {}): {}",
         _conf->get_host(), _conf->get_port(), _is_ready_count, e.what());
     return nullptr;
@@ -76,5 +77,5 @@ std::shared_ptr<io::stream> connector::open() {
  * @return std::shared_ptr<stream>
  */
 std::shared_ptr<io::stream> connector::create_stream() {
-  return std::make_shared<stream>(_conf, _logger);
+  return std::make_shared<stream>(_conf);
 }
