@@ -1,26 +1,25 @@
 /**
-* Copyright 2011-2013 Centreon
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*     http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*
-* For more information : contact@centreon.com
-*/
+ * Copyright 2011-2013 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/logging/syslogger.hh"
 #include <syslog.h>
 #include <cstdlib>
-#include "com/centreon/exceptions/basic.hh"
-#include "com/centreon/misc/stringifier.hh"
+#include "com/centreon/exceptions/msg_fmt.hh"
 
 using namespace com::centreon::logging;
 
@@ -78,11 +77,10 @@ void syslogger::log(uint64_t types,
   (void)verbose;
   (void)size;
 
-  misc::stringifier header;
-  _build_header(header);
+  std::string header = _build_header();
 
   std::lock_guard<std::recursive_mutex> lock(_lock);
-  syslog(LOG_ERR, "%s%s", header.data(), msg);
+  syslog(LOG_ERR, "%s%s", header.c_str(), msg);
 }
 
 /**
