@@ -17,13 +17,13 @@
  *
  */
 #include "parser.hh"
-#include <memory>
+#include <absl/strings/match.h>
+#include "anomalydetection_helper.hh"
+#include "com/centreon/common/file.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "command_helper.hh"
 #include "common/engine_conf/state.pb.h"
 #include "common/log_v2/log_v2.hh"
-
-#include "anomalydetection_helper.hh"
-#include "command_helper.hh"
 #include "connector_helper.hh"
 #include "contact_helper.hh"
 #include "contactgroup_helper.hh"
@@ -51,28 +51,6 @@ using ::google::protobuf::FieldDescriptor;
 using ::google::protobuf::Message;
 using ::google::protobuf::Reflection;
 
-/**
- * @brief Reads the content of a text file and returns it in an std::string.
- *
- * @param file_path The file to read.
- *
- * @return The content as an std::string.
- */
-static std::string read_file_content(const std::filesystem::path& file_path) {
-  std::ifstream in(file_path, std::ios::in);
-  std::string retval;
-  if (in) {
-    in.seekg(0, std::ios::end);
-    retval.resize(in.tellg());
-    in.seekg(0, std::ios::beg);
-    in.read(&retval[0], retval.size());
-    in.close();
-  } else
-    throw msg_fmt("Parsing of resource file failed: can't open file '{}': {}",
-                  file_path.string(), strerror(errno));
-  return retval;
-}
-
 /**
  *  Default constructor.
  *
@@ -86,7 +64,7 @@ parser::parser() : _logger{log_v2::instance().get(log_v2::CONFIG)} {}
  *  @param[in] pb_config The state configuration to fill.
  *  @param[out] err   The config warnings/errors counter.
  */
-void parser::parse(std::string const& path, State* pb_config, error_cnt& err) {
+void parser::parse(const std::string& path, State* pb_config, error_cnt& err) {
   /* Parse the global configuration file. */
   auto helper = std::make_unique<state_helper>(pb_config);
   _pb_helper[pb_config] = std::move(helper);
@@ -160,7 +138,7 @@ void parser::_parse_global_configuration(const std::string& path,
                                          State* pb_config) {
   _logger->info("Reading main configuration file '{}'.", path);
 
-  std::string content = read_file_content(path);
+  std::string content = common::read_file_content(path);
 
   pb_config->set_cfg_main(path);
   _current_line = 0;
@@ -186,6 +164,39 @@ void parser::_parse_global_configuration(const std::string& path,
                        p.second);
     }
   }
+
+  /* A bad hook so that Engine stays compatible with previous
+   * versions. */
+  for (auto& m : pb_config->broker_module()) {
+    if (absl::StrContains(m, "cbmod.so")) {
+      auto arr = absl::StrSplit(m, absl::ByAnyChar(" \t\n"), absl::SkipEmpty());
+      auto it = arr.begin();
+      std::string_view module_name;
+      if (it != arr.end()) {
+        module_name = *it;
+        ++it;
+        if (it != arr.end()) {
+          std::string_view module_args = *it;
+          module_args = absl::StripAsciiWhitespace(module_args);
+          if (pb_config->broker_module_cfg_file().empty()) {
+            pb_config->set_broker_module_cfg_file(
+                std::string(module_args.data(), module_args.size()));
+            _logger->warn(
+                "Parsing the configuration file '{}' of the 'cbmod' module "
+                "to "
+                "still be able to use it.",
+                module_args);
+          } else {
+            _logger->warn(
+                "The new 'broker_module_cfg_file' field is already set, so "
+                "nothing done with the 'cbmod' module configuration file '{}'.",
+                module_args);
+          }
+        }
+      }
+      break;
+    }
+  }
 }
 
 /**
@@ -196,12 +207,12 @@ void parser::_parse_global_configuration(const std::string& path,
  * from the message format.
  *
  * Two mechanisms are used to complete the reflection.
- * * A hastable <string, string> named correspondence is used in case of several
- *   keys to access to the same value. This is, for example, the case for
- *   host_id which is historically also named _HOST_ID.
+ * * A hastable <string, string> named correspondence is used in case of
+ * several keys to access to the same value. This is, for example, the case
+ * for host_id which is historically also named _HOST_ID.
  * * A std::function<bool(string_view_string_view) can also be defined in
- *   several cases to make special stuffs. For example, we use it for timeperiod
- *   object to set its timeranges.
+ *   several cases to make special stuffs. For example, we use it for
+ * timeperiod object to set its timeranges.
  *
  * @param path The file to parse.
  * @param pb_config The configuration to complete.
@@ -210,7 +221,7 @@ void parser::_parse_object_definitions(const std::string& path,
                                        State* pb_config) {
   _logger->info("Processing object config file '{}'", path);
 
-  std::string content = read_file_content(path);
+  std::string content = common::read_file_content(path);
 
   auto tab{absl::StrSplit(content, '\n')};
   std::string ll;
@@ -273,6 +284,8 @@ void parser::_parse_object_definitions(const std::string& path,
             }
           }
           if (obj.register_()) {
+            // final object => we apply default values
+            _pb_helper[msg.get()]->set_default_values();
             switch (otype) {
               case message_helper::contact:
                 pb_config->mutable_contacts()->AddAllocated(
@@ -364,7 +377,8 @@ void parser::_parse_object_definitions(const std::string& path,
           if (!msg_helper->set(key, l)) {
             if (!msg_helper->insert_customvariable(key, l))
               throw msg_fmt(
-                  "Unable to parse '{}' key with value '{}' in message of type "
+                  "Unable to parse '{}' key with value '{}' in message of "
+                  "type "
                   "'{}'",
                   key, l, type);
           }
@@ -464,7 +478,7 @@ void parser::_parse_object_definitions(const std::string& path,
 void parser::_parse_resource_file(const std::string& path, State* pb_config) {
   _logger->info("Reading resource file '{}'", path);
 
-  std::string content = read_file_content(path);
+  std::string content = common::read_file_content(path);
 
   auto tab{absl::StrSplit(content, '\n')};
   int current_line = 1;
@@ -526,6 +540,14 @@ void parser::_resolve_template(State* pb_config, error_cnt& err) {
     _resolve_template(_pb_helper[&he],
                       _pb_templates[message_helper::hostescalation]);
 
+  for (Hostgroup& hg : *pb_config->mutable_hostgroups())
+    _resolve_template(_pb_helper[&hg],
+                      _pb_templates[message_helper::hostgroup]);
+
+  for (Servicegroup& sg : *pb_config->mutable_servicegroups())
+    _resolve_template(_pb_helper[&sg],
+                      _pb_templates[message_helper::servicegroup]);
+
   for (const Command& c : pb_config->commands())
     _pb_helper.at(&c)->check_validity(err);
 
@@ -588,7 +610,8 @@ void parser::_resolve_template(State* pb_config, error_cnt& err) {
 }
 
 /**
- * @brief Resolvers a message given by its helper and using the given templates.
+ * @brief Resolvers a message given by its helper and using the given
+ * templates.
  *
  * @param msg_helper The message helper.
  * @param tmpls The templates to use.
@@ -617,9 +640,9 @@ void parser::_resolve_template(std::unique_ptr<message_helper>& msg_helper,
 }
 
 /**
- * @brief For each unchanged field in the Protobuf object stored in msg_helper,
- * we copy the corresponding field from tmpl. This is the key for the
- * inheritence with cfg files.
+ * @brief For each unchanged field in the Protobuf object stored in
+ * msg_helper, we copy the corresponding field from tmpl. This is the key for
+ * the inheritence with cfg files.
  *
  * @param msg_helper A message_help holding a protobuf message
  * @param tmpl A template of the same type as the on in the msg_helper
@@ -664,7 +687,11 @@ void parser::_merge(std::unique_ptr<message_helper>& msg_helper,
                 if (!found)
                   refl->AddString(msg, f, s);
               }
-              msg_helper->set_changed(f->index());
+              // in conf files address are referenced by address1, address2....
+              // so we have to merge them
+              if (f->name() != "address") {
+                msg_helper->set_changed(f->index());
+              }
             } break;
             case FieldDescriptor::CPPTYPE_MESSAGE: {
               size_t count = refl->FieldSize(*tmpl, f);
@@ -695,7 +722,7 @@ void parser::_merge(std::unique_ptr<message_helper>& msg_helper,
                       const CustomVariable& cv1 =
                           static_cast<const CustomVariable&>(m1);
                       if (cv.name() == cv1.name()) {
-                        _logger->info("same name");
+                        _logger->debug("same name");
                         found = true;
                         break;
                       }
@@ -709,7 +736,10 @@ void parser::_merge(std::unique_ptr<message_helper>& msg_helper,
                   new_m->CopyFrom(m);
                 }
               }
-              msg_helper->set_changed(f->index());
+              // tags and custom variables are merged among templates
+              if (f->name() != "tags" && f->name() != "customvariables") {
+                msg_helper->set_changed(f->index());
+              }
             } break;
             default:
               _logger->error(
@@ -765,9 +795,10 @@ void parser::_merge(std::unique_ptr<message_helper>& msg_helper,
                     if (!found)
                       set->add_data(v);
                   }
-                } else if (set->data().empty())
+                } else if (set->data().empty()) {
                   *set->mutable_data() = orig_set->data();
-
+                  set->set_additive(orig_set->additive());
+                }
               } else if (d && d->name() == "StringList") {
                 StringList* orig_lst =
                     static_cast<StringList*>(refl->MutableMessage(tmpl, f));
@@ -776,10 +807,36 @@ void parser::_merge(std::unique_ptr<message_helper>& msg_helper,
                 if (lst->additive()) {
                   for (auto& v : orig_lst->data())
                     lst->add_data(v);
-                } else if (lst->data().empty())
+                } else if (lst->data().empty()) {
                   *lst->mutable_data() = orig_lst->data();
+                  lst->set_additive(orig_lst->additive());
+                }
+              } else if (d && d->name() == "PairStringSet") {
+                PairStringSet* orig_pair =
+                    static_cast<PairStringSet*>(refl->MutableMessage(tmpl, f));
+                PairStringSet* pair =
+                    static_cast<PairStringSet*>(refl->MutableMessage(msg, f));
+                if (pair->additive()) {
+                  for (auto& v : orig_pair->data()) {
+                    bool found = false;
+                    for (auto& s : *pair->mutable_data()) {
+                      if (s.first() == v.first() && s.second() == v.second()) {
+                        found = true;
+                        break;
+                      }
+                    }
+                    if (!found)
+                      pair->add_data()->CopyFrom(v);
+                  }
+                } else if (pair->data().empty()) {
+                  *pair->mutable_data() = orig_pair->data();
+                  pair->set_additive(orig_pair->additive());
+                }
+              } else {
+                refl->MutableMessage(msg, f)->CopyFrom(
+                    refl->GetMessage(*tmpl, f));
+                msg_helper->set_changed(f->index());
               }
-              msg_helper->set_changed(f->index());
             } break;
 
             default:
