@@ -17,11 +17,19 @@
  *
  */
 #include "common/engine_conf/state_helper.hh"
-#include <fmt/format.h>
 #include <google/protobuf/descriptor.h>
 #include <rapidjson/rapidjson.h>
 #include "com/centreon/engine/events/sched_info.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "common/engine_conf/contact_helper.hh"
+#include "common/engine_conf/contactgroup_helper.hh"
+#include "common/engine_conf/host_helper.hh"
+#include "common/engine_conf/hostdependency_helper.hh"
+#include "common/engine_conf/hostescalation_helper.hh"
+#include "common/engine_conf/service_helper.hh"
+#include "common/engine_conf/servicedependency_helper.hh"
+#include "common/engine_conf/serviceescalation_helper.hh"
+#include "common/engine_conf/servicegroup_helper.hh"
 #include "common/log_v2/log_v2.hh"
 
 using com::centreon::common::log_v2::log_v2;
@@ -69,7 +77,7 @@ state_helper::state_helper(State* obj)
  * @param key The key to parse.
  * @param value The value corresponding to the key
  */
-bool state_helper::hook(std::string_view key, const std::string_view& value) {
+bool state_helper::hook(std::string_view key, std::string_view value) {
   State* obj = static_cast<State*>(mut_obj());
   /* Since we use key to get back the good key value, it is faster to give key
    * by copy to the method. We avoid one key allocation... */
@@ -77,13 +85,15 @@ bool state_helper::hook(std::string_view key, const std::string_view& value) {
 
   if (key.substr(0, 10) == "log_level_") {
     if (value == "off" || value == "critical" || value == "error" ||
-        value == "warning" || value == "info" || value == "debug" ||
-        value == "trace") {
+        value == "err" || value == "warning" || value == "info" ||
+        value == "debug" || value == "trace") {
+      if (value == "err")
+        value = "error";
       return set_global(key, value);
     } else
       throw msg_fmt(
           "Log level '{}' has value '{}' but it cannot be a different string "
-          "than off, critical, error, warning, info, debug or trace",
+          "than off, critical, error, err, warning, info, debug or trace",
           key, value);
   } else if (key == "date_format") {
     if (value == "euro")
@@ -319,7 +329,7 @@ void state_helper::_init() {
   obj->set_use_setpgid(true);
   obj->set_use_syslog(true);
   obj->set_log_v2_enabled(true);
-  obj->set_log_legacy_enabled(true);
+  obj->set_log_legacy_enabled(false);
   obj->set_log_v2_logger("file");
   obj->set_log_level_functions(LogLevel::error);
   obj->set_log_level_config(LogLevel::info);
@@ -440,7 +450,10 @@ bool state_helper::set_global(const std::string_view& key,
           fill_string_group(lst, value);
           return true;
         }
+      } else {
+        assert(124 == 123);
       }
+      break;
     default:
       return false;
   }
@@ -498,4 +511,100 @@ bool state_helper::apply_extended_conf(
   }
   return retval;
 }
+
+/**
+ * @brief Expand configuration objects.
+ *
+ * @param pb_config The protobuf configuration state to expand.
+ * @param err The error count object to update in case of errors.
+ */
+void state_helper::expand(configuration::error_cnt& err) {
+  configuration::State& pb_config = *static_cast<State*>(mut_obj());
+
+  absl::flat_hash_map<std::string, configuration::Host> m_host;
+  for (auto& h : pb_config.hosts()) {
+    m_host.emplace(h.host_name(), h);
+  }
+
+  absl::flat_hash_map<std::string, configuration::Contactgroup*>
+      m_contactgroups;
+  for (auto& cg : *pb_config.mutable_contactgroups()) {
+    m_contactgroups.emplace(cg.contactgroup_name(), &cg);
+  }
+
+  absl::flat_hash_map<std::string, configuration::Hostgroup*> m_hostgroups;
+  for (auto& hg : *pb_config.mutable_hostgroups()) {
+    m_hostgroups.emplace(hg.hostgroup_name(), &hg);
+  }
+
+  absl::flat_hash_map<std::string, configuration::Servicegroup*>
+      m_servicegroups;
+  for (auto& sg : *pb_config.mutable_servicegroups())
+    m_servicegroups.emplace(sg.servicegroup_name(), &sg);
+
+  // Expand contacts
+  contact_helper::expand(pb_config, err, m_contactgroups);
+  // Expand contactgroups
+  contactgroup_helper::expand(pb_config, err, m_contactgroups);
+  // Expand hosts
+  host_helper::expand(pb_config, err, m_hostgroups);
+  // Expand services
+  service_helper::expand(pb_config, err, m_host, m_servicegroups);
+
+  // Expand servicegroups
+  servicegroup_helper::expand(pb_config, err, m_servicegroups);
+
+  // Expand hostdependencies.
+  hostdependency_helper::expand(pb_config, err, m_hostgroups);
+  // Expand servicedependencies.
+  servicedependency_helper::expand(pb_config, err, m_hostgroups,
+                                   m_servicegroups);
+
+  // Expand hostescalations
+  hostescalation_helper::expand(pb_config, err, m_hostgroups);
+  // Expand serviceescalations
+  serviceescalation_helper::expand(pb_config, err, m_hostgroups,
+                                   m_servicegroups);
+  // Expand custom variables
+  state_helper::_expand_cv(pb_config);
+}
+
+void state_helper::_expand_cv(configuration::State& s) {
+  absl::flat_hash_set<std::string_view> cvs;
+  for (auto& cv : s.macros_filter().data())
+    cvs.emplace(cv);
+
+  // Browse all anomalydetections.
+  for (auto& ad_cfg : *s.mutable_anomalydetections()) {
+    // Should custom variables be sent to broker ?
+    for (auto& cv : *ad_cfg.mutable_customvariables()) {
+      if (!s.enable_macros_filter() || cvs.contains(cv.name()))
+        cv.set_is_sent(true);
+    }
+  }
+  // Browse all contacts.
+  for (auto& c : *s.mutable_contacts()) {
+    // Should custom variables be sent to broker ?
+    for (auto& cv : *c.mutable_customvariables()) {
+      if (!s.enable_macros_filter() || cvs.contains(cv.name()))
+        cv.set_is_sent(true);
+    }
+  }
+  // Browse all hosts.
+  for (auto& host_cfg : *s.mutable_hosts()) {
+    // Should custom variables be sent to broker ?
+    for (auto& cv : *host_cfg.mutable_customvariables()) {
+      if (!s.enable_macros_filter() || cvs.contains(cv.name()))
+        cv.set_is_sent(true);
+    }
+  }
+  // Browse all services.
+  for (auto& service_cfg : *s.mutable_services()) {
+    // Should custom variables be sent to broker ?
+    for (auto& cv : *service_cfg.mutable_customvariables()) {
+      if (!s.enable_macros_filter() || cvs.contains(cv.name()))
+        cv.set_is_sent(true);
+    }
+  }
+}
 }  // namespace com::centreon::engine::configuration
