@@ -48,7 +48,7 @@ request_base::request_base() {
 }
 
 request_base::request_base(boost::beast::http::verb method,
-                           const std::string& server_name,
+                           const std::string_view& server_name,
                            boost::beast::string_view target)
     : request_type(method, target, 11) {
   set(boost::beast::http::field::host, server_name);
@@ -189,18 +189,17 @@ void http_connection::connect(connect_callback_type&& callback) {
                       *_conf);
   std::lock_guard<std::mutex> l(_socket_m);
   _socket.expires_after(_conf->get_connect_timeout());
-  if (_conf->get_endpoints().empty()) {
+  if (_conf->get_endpoints().empty())
     _socket.async_connect(
         _conf->get_endpoint(),
         [me = shared_from_this(), cb = std::move(callback)](
             const boost::beast::error_code& err) { me->on_connect(err, cb); });
-  } else {
+  else
     _socket.async_connect(_conf->get_endpoints(),
                           [me = shared_from_this(), cb = std::move(callback)](
                               const boost::beast::error_code& err,
-                              const typename asio::ip::tcp::endpoint& endpoint
+                              const asio::ip::tcp::endpoint& endpoint
                               [[maybe_unused]]) { me->on_connect(err, cb); });
-  }
 }
 
 /**
@@ -212,10 +211,16 @@ void http_connection::connect(connect_callback_type&& callback) {
  */
 void http_connection::on_connect(const boost::beast::error_code& err,
                                  const connect_callback_type& callback) {
+  std::string detail;
   if (err) {
-    std::string detail =
-        fmt::format("{:p} fail connect to {}: {}", static_cast<void*>(this),
-                    _conf->get_endpoint(), err.message());
+    if (_conf->get_endpoints().empty())
+      detail =
+          fmt::format("{:p} fail connect to {}: {}", static_cast<void*>(this),
+                      _conf->get_endpoint(), err.message());
+    else
+      detail =
+          fmt::format("{:p} fail connect to {}: {}", static_cast<void*>(this),
+                      _conf->get_server_name(), err.message());
     SPDLOG_LOGGER_ERROR(_logger, detail);
     callback(err, detail);
     shutdown();
