@@ -39,6 +39,7 @@ class server_bireactor
                    const otel_request_handler& handler,
                    const std::shared_ptr<spdlog::logger>& logger,
                    const std::string& peer,
+                   bool is_crypted,
                    agent_stat::pointer& stats)
       : agent_impl<::grpc::ServerBidiReactor<agent::MessageFromAgent,
                                              agent::MessageToAgent>>(
@@ -48,6 +49,7 @@ class server_bireactor
             handler,
             logger,
             false,
+            is_crypted,
             stats),
         _peer(peer) {
     SPDLOG_LOGGER_DEBUG(_logger, "connected with agent {}", _peer);
@@ -59,6 +61,7 @@ class server_bireactor
                    const otel_request_handler& handler,
                    const std::shared_ptr<spdlog::logger>& logger,
                    const std::string& peer,
+                   bool is_crypted,
                    agent_stat::pointer& stats,
                    const std::chrono::system_clock::time_point& exp_time)
       : agent_impl<::grpc::ServerBidiReactor<agent::MessageFromAgent,
@@ -69,6 +72,7 @@ class server_bireactor
             handler,
             logger,
             false,
+            is_crypted,
             stats,
             exp_time),
         _peer(peer) {
@@ -178,7 +182,7 @@ void agent_service::init() {
 agent_service::Export(::grpc::CallbackServerContext* context) {
   std::chrono::system_clock::time_point exp_time =
       std::chrono::system_clock::time_point::min();
-  if (_is_crypted && !_trusted_tokens->empty()) {
+  if (_is_crypted) {
     auto auth_ctx = context->auth_context();
     if (auth_ctx) {
       // Grab *all* "authorization" metadata values (often just one).
@@ -186,13 +190,14 @@ agent_service::Export(::grpc::CallbackServerContext* context) {
       auto auth_md = metadata.find("authorization");
       if (auth_md != metadata.end()) {
         std::string auth_header(auth_md->second.data(), auth_md->second.size());
-        SPDLOG_LOGGER_DEBUG(_logger, "Token found in Metadata");
+        SPDLOG_LOGGER_INFO(_logger, "Token found in Metadata");
         try {
           common::crypto::jwt jwt(auth_header);
           if (jwt.get_exp() < std::chrono::system_clock::now()) {
             SPDLOG_LOGGER_ERROR(_logger, "UNAUTHENTICATED : Token expired");
             return new ImmediateFinishReactor(::grpc::Status(
                 ::grpc::StatusCode::UNAUTHENTICATED, "Token expired"));
+            ;
           }
           // check if token is trusted by the service
           if (_trusted_tokens->find(jwt.get_string()) ==
@@ -203,7 +208,7 @@ agent_service::Export(::grpc::CallbackServerContext* context) {
                 ::grpc::StatusCode::UNAUTHENTICATED, "Token not trusted"));
           }
 
-          SPDLOG_LOGGER_DEBUG(_logger, "Token is valid");
+          SPDLOG_LOGGER_INFO(_logger, "Token is valid");
           exp_time = jwt.get_exp();
         } catch (const exceptions::msg_fmt& ex) {
           SPDLOG_LOGGER_ERROR(_logger, "Error: {}", ex.what());
@@ -228,8 +233,8 @@ agent_service::Export(::grpc::CallbackServerContext* context) {
   {
     absl::MutexLock l(&_conf_m);
     new_reactor = std::make_shared<server_bireactor>(
-        _io_context, _conf, _metric_handler, _logger, context->peer(), _stats,
-        exp_time);
+        _io_context, _conf, _metric_handler, _logger, context->peer(),
+        _is_crypted, _stats, exp_time);
   }
   server_bireactor::register_stream(new_reactor);
   new_reactor->start_read();
