@@ -167,7 +167,7 @@ class cancellable_command : public command {
                nagios_macros& macors,
                uint32_t timeout,
                const check_result::pointer& to_push_to_checker,
-               const void* caller = nullptr) override;
+               const notifier* caller = nullptr) override;
   void run(const std::string& process_cmd,
            nagios_macros& macros,
            uint32_t timeout,
@@ -198,7 +198,7 @@ uint64_t cancellable_command::run(
     nagios_macros& macros,
     uint32_t timeout,
     const check_result::pointer& to_push_to_checker,
-    const void* caller) {
+    const notifier* caller) {
   if (_fake_result) {
     checks::checker::instance().add_check_result_to_reap(_fake_result);
     SPDLOG_LOGGER_DEBUG(checks_logger,
@@ -351,7 +351,6 @@ const anomalydetection::pointer_set& anomalydetection::get_anomaly(
  *                                          metric thresholds.
  *  @param[in] status_change                Should we follow the thresholds file
  *                                          to determine status.
- *  @param[in] initial_state                Initial service state.
  *  @param[in] max_attempts                 Max check attempts.
  *  @param[in] accept_passive_checks        Does this service accept
  *                                          check result submission ?
@@ -428,7 +427,6 @@ anomalydetection::anomalydetection(uint64_t host_id,
                                    bool status_change,
                                    bool checks_enabled,
                                    bool accept_passive_checks,
-                                   enum service::service_state initial_state,
                                    uint32_t check_interval,
                                    uint32_t retry_interval,
                                    uint32_t notification_interval,
@@ -460,7 +458,6 @@ anomalydetection::anomalydetection(uint64_t host_id,
               "",
               checks_enabled,
               accept_passive_checks,
-              initial_state,
               check_interval,
               retry_interval,
               notification_interval,
@@ -519,7 +516,6 @@ anomalydetection::~anomalydetection() {
  *  @param[in] thresholds_file,             fullname to the thresholds file.
  *  @param[in] status_change,               should we follow the thresholds file
  *                                          to determine status.
- *  @param[in] initial_state                Initial service state.
  *  @param[in] max_attempts                 Max check attempts.
  *  @param[in] accept_passive_checks        Does this service accept
  *                                          check result submission ?
@@ -595,7 +591,6 @@ com::centreon::engine::anomalydetection* add_anomalydetection(
     std::string const& metric_name,
     std::string const& thresholds_file,
     bool status_change,
-    com::centreon::engine::service::service_state initial_state,
     int max_attempts,
     double check_interval,
     double retry_interval,
@@ -765,14 +760,14 @@ com::centreon::engine::anomalydetection* add_anomalydetection(
       host_id, service_id, host_name, description,
       display_name.empty() ? description : display_name, internal_id,
       dependent_service, metric_name, thresholds_file, status_change,
-      checks_enabled, accept_passive_checks, initial_state, check_interval,
-      retry_interval, notification_interval, max_attempts,
-      first_notification_delay, recovery_notification_delay,
-      notification_period, notifications_enabled, is_volatile, event_handler,
-      event_handler_enabled, notes, notes_url, action_url, icon_image,
-      icon_image_alt, flap_detection_enabled, low_flap_threshold,
-      high_flap_threshold, check_freshness, freshness_threshold,
-      obsess_over_service, timezone, icon_id, sensitivity)};
+      checks_enabled, accept_passive_checks, check_interval, retry_interval,
+      notification_interval, max_attempts, first_notification_delay,
+      recovery_notification_delay, notification_period, notifications_enabled,
+      is_volatile, event_handler, event_handler_enabled, notes, notes_url,
+      action_url, icon_image, icon_image_alt, flap_detection_enabled,
+      low_flap_threshold, high_flap_threshold, check_freshness,
+      freshness_threshold, obsess_over_service, timezone, icon_id,
+      sensitivity)};
   try {
     obj->set_acknowledgement(AckType::NONE);
     obj->set_check_options(CHECK_OPTION_NONE);
@@ -963,8 +958,8 @@ int anomalydetection::handle_async_check_result(
   std::string plugin_output;
   std::string long_plugin_output;
   std::string perf_data;
-  common::parse_check_output(output, plugin_output, long_plugin_output,
-                             perf_data, true, false);
+  parse_check_output(output, plugin_output, long_plugin_output, perf_data, true,
+                     false);
 
   perf_data = string::extract_perfdata(perf_data, _metric_name);
 
