@@ -36,7 +36,7 @@ using namespace com::centreon;
 using namespace com::centreon::engine::logging;
 using namespace com::centreon::engine::checks;
 
-checker* checker::_instance = nullptr;
+std::shared_ptr<checker> checker::_instance;
 static constexpr time_t max_check_reaper_time = 30;
 
 /**
@@ -53,14 +53,11 @@ checker& checker::instance() {
 
 void checker::init(bool used_by_test) {
   if (!_instance)
-    _instance = new checker(used_by_test);
+    _instance = std::make_shared<checker>(used_by_test);
 }
 
 void checker::deinit() {
-  if (_instance) {
-    delete _instance;
-    _instance = nullptr;
-  }
+  _instance.reset();
 }
 
 void checker::clear() noexcept {
@@ -328,10 +325,6 @@ void checker::run_sync(host* hst,
       << "* Sync host check done: new state=" << hst->get_current_state();
   SPDLOG_LOGGER_DEBUG(checks_logger, "* Sync host check done: new state={}",
                       static_cast<uint32_t>(hst->get_current_state()));
-
-  // Send event broker.
-  broker_host_check(NEBTYPE_HOSTCHECK_PROCESSED, hst, checkable::check_active,
-                    nullptr);
 }
 
 /**************************************
@@ -344,13 +337,18 @@ void checker::run_sync(host* hst,
  *  Default constructor.
  */
 checker::checker(bool used_by_test)
-    : commands::command_listener(), _used_by_test(used_by_test) {}
+    : commands::command_listener(), _used_by_test(used_by_test) {
+  SPDLOG_LOGGER_DEBUG(commands_logger, "create checker {:p}",
+                      static_cast<const void*>(this));
+}
 
 /**
  *  Default destructor.
  */
-checker::~checker() noexcept {
+checker::~checker() {
   clear();
+  SPDLOG_LOGGER_DEBUG(commands_logger, "delete checker {:p}",
+                      static_cast<const void*>(this));
 }
 
 /**
@@ -447,12 +445,6 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Send broker event.
   timeval start_time{0, 0};
   timeval end_time{0, 0};
-  int ret(broker_host_check(NEBTYPE_HOSTCHECK_SYNC_PRECHECK, hst,
-                            checkable::check_active, nullptr));
-
-  // Host sync check was cancelled or overriden by NEB module.
-  if ((NEBERROR_CALLBACKCANCEL == ret) || (NEBERROR_CALLBACKOVERRIDE == ret))
-    return hst->get_current_state();
 
   // Get current host macros.
   nagios_macros* macros(get_global_macros());
@@ -470,11 +462,6 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get command object.
   commands::command::pointer cmd = hst->get_check_command_ptr();
   std::string processed_cmd(cmd->process_cmd(macros));
-  const char* tmp_processed_cmd = processed_cmd.c_str();
-
-  // Send broker event.
-  broker_host_check(NEBTYPE_HOSTCHECK_RAW_START, hst, checkable::check_active,
-                    processed_cmd.c_str());
 
   // Debug messages.
   engine_logger(dbg_commands, more)
@@ -611,10 +598,6 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   // Get the end time of command.
   gettimeofday(&end_time, nullptr);
 
-  // Send broker event.
-  broker_host_check(NEBTYPE_HOSTCHECK_RAW_END, hst, checkable::check_active,
-                    tmp_processed_cmd);
-
   // Termination.
   engine_logger(dbg_checks, basic)
       << "** Sync host check done: state=" << return_result;
