@@ -39,7 +39,7 @@ constexpr std::string_view _query_ending("\0\0\0\0", 4);
 connector::connector(const std::string& connector_name,
                      const std::string& connector_line,
                      const std::shared_ptr<asio::io_context>& io_context,
-                     command_listener* listener)
+                     const std::shared_ptr<command_listener>& listener)
     : command(connector_name, connector_line, listener, e_type::connector),
       _state(e_state::not_started),
       _logger(commands_logger),
@@ -70,7 +70,7 @@ std::shared_ptr<connector> connector::load(
     std::string const& connector_name,
     std::string const& connector_line,
     const std::shared_ptr<asio::io_context>& io_context,
-    command_listener* listener) {
+    const std::shared_ptr<command_listener>& listener) {
   std::shared_ptr<connector> ret(
       new connector(connector_name, connector_line, io_context, listener));
   ret->_timeout_timer_start();
@@ -608,7 +608,6 @@ void connector::_recv_query_version(const std::string_view& data) {
   try {
     // Parse query version response to get major and minor
     // engine version supported by the connector.
-    unsigned length = data.size();
     unsigned major, minor;
     auto major_minor_sep = data.find('\0');
     if (major_minor_sep == std::string_view::npos) {
