@@ -1,22 +1,20 @@
 /**
  * Copyright 2011-2024 Centreon
  *
- * This file is part of Centreon Engine.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Centreon Engine is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * Centreon Engine is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
- * You should have received a copy of the GNU General Public License
- * along with Centreon Engine. If not, see
- * <http://www.gnu.org/licenses/>.
+ * For more information : contact@centreon.com
  */
-
 #include "com/centreon/engine/escalation.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/globals.hh"
@@ -31,16 +29,16 @@ escalation::escalation(uint32_t first_notification,
                        double notification_interval,
                        std::string const& escalation_period,
                        uint32_t escalate_on,
-                       Uuid const& uuid)
-    : notifier_ptr{nullptr},
-      escalation_period_ptr{nullptr},
-      _first_notification{first_notification},
+                       const size_t key)
+    : _first_notification{first_notification},
       _last_notification{last_notification},
       _notification_interval{
           (notification_interval < 0) ? 0 : notification_interval},
       _escalation_period{escalation_period},
       _escalate_on{escalate_on},
-      _uuid{uuid} {}
+      _internal_key{key},
+      notifier_ptr{nullptr},
+      escalation_period_ptr{nullptr} {}
 
 std::string const& escalation::get_escalation_period() const {
   return _escalation_period;
@@ -115,8 +113,8 @@ bool escalation::is_viable(int state __attribute__((unused)),
   return true;
 }
 
-void escalation::resolve(int& w __attribute__((unused)), int& e) {
-  int errors{0};
+void escalation::resolve(uint32_t& w [[maybe_unused]], uint32_t& e) {
+  uint32_t errors = 0;
   // Find the timeperiod.
   if (!get_escalation_period().empty()) {
     timeperiod_map::const_iterator it{
@@ -167,6 +165,6 @@ void escalation::resolve(int& w __attribute__((unused)), int& e) {
   }
 }
 
-Uuid const& escalation::get_uuid() const {
-  return _uuid;
+size_t escalation::internal_key() const {
+  return _internal_key;
 }
