@@ -52,15 +52,9 @@ int obsessive_compulsive_host_check_processor(
 
   bool obsess_over_hosts;
   uint32_t ochp_timeout;
-#ifdef LEGACY_CONF
-  obsess_over_hosts = config->obsess_over_hosts();
-  const std::string& ochp_command = config->ochp_command();
-  ochp_timeout = config->ochp_timeout();
-#else
   obsess_over_hosts = pb_config.obsess_over_hosts();
   const std::string& ochp_command = pb_config.ochp_command();
   ochp_timeout = pb_config.ochp_timeout();
-#endif
 
   engine_logger(dbg_functions, basic)
       << "obsessive_compulsive_host_check_processor()";
@@ -117,8 +111,8 @@ int obsessive_compulsive_host_check_processor(
     /* run the command */
     try {
       std::string tmp;
-      my_system_r(mac, processed_command, ochp_timeout,
-                  &early_timeout, &exectime, tmp, 0);
+      my_system_r(mac, processed_command, ochp_timeout, &early_timeout,
+                  &exectime, tmp, 0);
     } catch (std::exception const& e) {
       engine_logger(log_runtime_error, basic)
           << "Error: can't execute compulsive host processor command line '"
@@ -140,8 +134,7 @@ int obsessive_compulsive_host_check_processor(
   if (early_timeout)
     engine_logger(log_runtime_warning, basic)
         << "Warning: OCHP command '" << processed_command << "' for host '"
-        << hst->name() << "' timed out after " << ochp_timeout
-        << " seconds";
+        << hst->name() << "' timed out after " << ochp_timeout << " seconds";
   runtime_logger->warn(
       "Warning: OCHP command '{}' for host '{}' timed out after {} seconds",
       processed_command, hst->name(), ochp_timeout);
@@ -171,17 +164,11 @@ int run_global_service_event_handler(nagios_macros* mac,
   bool enable_event_handlers;
   bool log_event_handlers;
   uint32_t event_handler_timeout;
-#ifdef LEGACY_CONF
-  enable_event_handlers = config->enable_event_handlers();
-  const std::string& global_service_event_handler = config->global_service_event_handler();
-  log_event_handlers = config->log_event_handlers();
-  event_handler_timeout = config->event_handler_timeout();
-#else
   enable_event_handlers = pb_config.enable_event_handlers();
-  const std::string& global_service_event_handler = pb_config.global_service_event_handler();
+  const std::string& global_service_event_handler =
+      pb_config.global_service_event_handler();
   log_event_handlers = pb_config.log_event_handlers();
   event_handler_timeout = pb_config.event_handler_timeout();
-#endif
 
   if (svc == nullptr)
     return ERROR;
@@ -206,8 +193,8 @@ int run_global_service_event_handler(nagios_macros* mac,
 
   /* get the raw command line */
   get_raw_command_line_r(mac, global_service_event_handler_ptr,
-                         global_service_event_handler.c_str(),
-                         raw_command, macro_options);
+                         global_service_event_handler.c_str(), raw_command,
+                         macro_options);
   if (raw_command.empty())
     return ERROR;
 
@@ -246,8 +233,8 @@ int run_global_service_event_handler(nagios_macros* mac,
                                                  cached_cmd)) {
     /* run the command */
     try {
-      my_system_r(mac, processed_command, event_handler_timeout,
-                  &early_timeout, &exectime, command_output, 0);
+      my_system_r(mac, processed_command, event_handler_timeout, &early_timeout,
+                  &exectime, command_output, 0);
     } catch (std::exception const& e) {
       engine_logger(log_runtime_error, basic)
           << "Error: can't execute global service event handler "
@@ -269,8 +256,8 @@ int run_global_service_event_handler(nagios_macros* mac,
   if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Global service event handler command '"
-        << processed_command << "' timed out after "
-        << event_handler_timeout << " seconds";
+        << processed_command << "' timed out after " << event_handler_timeout
+        << " seconds";
     events_logger->info(
         "Warning: Global service event handler command '{}' timed out after {} "
         "seconds",
@@ -293,13 +280,8 @@ int run_service_event_handler(nagios_macros* mac,
 
   bool log_event_handlers;
   uint32_t event_handler_timeout;
-#ifdef LEGACY_CONF
-  log_event_handlers = config->log_event_handlers();
-  event_handler_timeout = config->event_handler_timeout();
-#else
   log_event_handlers = pb_config.log_event_handlers();
   event_handler_timeout = pb_config.event_handler_timeout();
-#endif
 
   engine_logger(dbg_functions, basic) << "run_service_event_handler()";
   functions_logger->trace("run_service_event_handler()");
@@ -357,8 +339,8 @@ int run_service_event_handler(nagios_macros* mac,
                                            checkable::EVH_TYPE)) {
     /* run the command */
     try {
-      my_system_r(mac, processed_command, event_handler_timeout,
-                  &early_timeout, &exectime, command_output, 0);
+      my_system_r(mac, processed_command, event_handler_timeout, &early_timeout,
+                  &exectime, command_output, 0);
     } catch (std::exception const& e) {
       engine_logger(log_runtime_error, basic)
           << "Error: can't execute service event handler command line '"
@@ -378,8 +360,7 @@ int run_service_event_handler(nagios_macros* mac,
   if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Service event handler command '" << processed_command
-        << "' timed out after " << event_handler_timeout
-        << " seconds";
+        << "' timed out after " << event_handler_timeout << " seconds";
     events_logger->info(
         "Warning: Service event handler command '{}' timed out after {} "
         "seconds",
@@ -404,19 +385,8 @@ int handle_host_event(com::centreon::engine::host* hst) {
 
   bool enable_event_handlers;
   std::string_view global_host_event_handler;
-#ifdef LEGACY_CONF
-  enable_event_handlers = config->enable_event_handlers();
-  global_host_event_handler = config->global_host_event_handler();
-#else
   enable_event_handlers = pb_config.enable_event_handlers();
   global_host_event_handler = pb_config.global_host_event_handler();
-#endif
-
-  /* send event data to broker */
-  broker_statechange_data(
-      NEBTYPE_STATECHANGE_END, NEBFLAG_NONE, NEBATTR_NONE, HOST_STATECHANGE,
-      (void*)hst, hst->get_current_state(), hst->get_state_type(),
-      hst->get_current_attempt(), hst->max_check_attempts(), nullptr);
 
   /* bail out if we shouldn't be running event handlers */
   if (!enable_event_handlers)
@@ -435,8 +405,7 @@ int handle_host_event(com::centreon::engine::host* hst) {
     run_host_event_handler(mac, hst);
 
   /* send data to event broker */
-  broker_external_command(NEBTYPE_EXTERNALCOMMAND_CHECK, CMD_NONE, nullptr,
-                          nullptr);
+  broker_external_command(NEBTYPE_EXTERNALCOMMAND_CHECK, CMD_NONE, nullptr);
 
   return OK;
 }
@@ -459,17 +428,11 @@ int run_global_host_event_handler(nagios_macros* mac,
   bool enable_event_handlers;
   bool log_event_handlers;
   uint32_t event_handler_timeout;
-#ifdef LEGACY_CONF
-  enable_event_handlers = config->enable_event_handlers();
-  const std::string& global_host_event_handler = config->global_host_event_handler();
-  log_event_handlers = config->log_event_handlers();
-  event_handler_timeout = config->event_handler_timeout();
-#else
   enable_event_handlers = pb_config.enable_event_handlers();
-  const std::string& global_host_event_handler = pb_config.global_host_event_handler();
+  const std::string& global_host_event_handler =
+      pb_config.global_host_event_handler();
   log_event_handlers = pb_config.log_event_handlers();
   event_handler_timeout = pb_config.event_handler_timeout();
-#endif
 
   if (hst == nullptr)
     return ERROR;
@@ -492,8 +455,8 @@ int run_global_host_event_handler(nagios_macros* mac,
 
   /* get the raw command line */
   get_raw_command_line_r(mac, global_host_event_handler_ptr,
-                         global_host_event_handler.c_str(),
-                         raw_command, macro_options);
+                         global_host_event_handler.c_str(), raw_command,
+                         macro_options);
   if (raw_command.empty())
     return ERROR;
 
@@ -529,8 +492,8 @@ int run_global_host_event_handler(nagios_macros* mac,
   if (host::command_is_allowed_by_whitelist(processed_command, cached_cmd)) {
     /* run the command */
     try {
-      my_system_r(mac, processed_command, event_handler_timeout,
-                  &early_timeout, &exectime, command_output, 0);
+      my_system_r(mac, processed_command, event_handler_timeout, &early_timeout,
+                  &exectime, command_output, 0);
     } catch (std::exception const& e) {
       engine_logger(log_runtime_error, basic)
           << "Error: can't execute global host event handler command line '"
@@ -551,8 +514,7 @@ int run_global_host_event_handler(nagios_macros* mac,
   if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Global host event handler command '" << processed_command
-        << "' timed out after " << event_handler_timeout
-        << " seconds";
+        << "' timed out after " << event_handler_timeout << " seconds";
     events_logger->info(
         "Warning: Global host event handler command '{}' timed out after {} "
         "seconds",
@@ -576,13 +538,8 @@ int run_host_event_handler(nagios_macros* mac,
 
   bool log_event_handlers;
   uint32_t event_handler_timeout;
-#ifdef LEGACY_CONF
-  log_event_handlers = config->log_event_handlers();
-  event_handler_timeout = config->event_handler_timeout();
-#else
   log_event_handlers = pb_config.log_event_handlers();
   event_handler_timeout = pb_config.event_handler_timeout();
-#endif
 
   engine_logger(dbg_functions, basic) << "run_host_event_handler()";
   functions_logger->trace("run_host_event_handler()");
@@ -636,8 +593,8 @@ int run_host_event_handler(nagios_macros* mac,
                                            checkable::EVH_TYPE)) {
     /* run the command */
     try {
-      my_system_r(mac, processed_command, event_handler_timeout,
-                  &early_timeout, &exectime, command_output, 0);
+      my_system_r(mac, processed_command, event_handler_timeout, &early_timeout,
+                  &exectime, command_output, 0);
     } catch (std::exception const& e) {
       engine_logger(log_runtime_error, basic)
           << "Error: can't execute host event handler command line '"
@@ -657,8 +614,7 @@ int run_host_event_handler(nagios_macros* mac,
   if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Host event handler command '" << processed_command
-        << "' timed out after " << event_handler_timeout
-        << " seconds";
+        << "' timed out after " << event_handler_timeout << " seconds";
     events_logger->info(
         "Warning: Host event handler command '{}' timed out after {} seconds",
         processed_command, event_handler_timeout);
