@@ -1,21 +1,21 @@
 /**
-* Copyright 2011-2013 Merethis
-*
-* This file is part of Centreon Engine.
-*
-* Centreon Engine is free software: you can redistribute it and/or
-* modify it under the terms of the GNU General Public License version 2
-* as published by the Free Software Foundation.
-*
-* Centreon Engine is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with Centreon Engine. If not, see
-* <http://www.gnu.org/licenses/>.
-*/
+ * Copyright 2011-2013 Merethis
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #include <cctype>
 #include <cerrno>
@@ -23,7 +23,7 @@
 #include <fstream>
 #include <thread>
 #include "com/centreon/engine/version.hh"
-#include "com/centreon/exceptions/basic.hh"
+#include "com/centreon/exceptions/msg_fmt.hh"
 #include "com/centreon/timestamp.hh"
 
 #define STATE_OK 0
@@ -31,8 +31,7 @@
 #define STATE_CRITICAL 2
 #define STATE_UNKNOWN 3
 
-// using namespace com::centreon;
-// using namespace com::centreon::engine;
+using com::centreon::exceptions::msg_fmt;
 
 /**
  *  Simulate a execution process.
@@ -119,17 +118,15 @@ static void query_execute(char const* q) {
   char* endptr(NULL);
   unsigned long command_id(strtol(startptr, &endptr, 10));
   if (startptr == endptr)
-    throw basic_error() << "invalid query execute: "
-                           "invalid command_id";
+    throw msg_fmt("invalid query execute: invalid command_id");
   startptr = endptr + 1;
   uint32_t timeout(strtol(startptr, &endptr, 10));
   if (startptr == endptr)
-    throw basic_error() << "invalid query execute: "
-                           "invalid is_executed";
+    throw msg_fmt("invalid query execute: invalid is_executed");
   startptr = endptr + 1;
   strtol(startptr, &endptr, 10);
   if (startptr == endptr)
-    throw basic_error() << "invalid query execute: invalid exit_code";
+    throw msg_fmt("invalid query execute: invalid exit_code");
   char const* cmd{endptr + 1};
 
   std::vector<std::string> cmdline = split(cmd);
@@ -141,7 +138,7 @@ static void query_execute(char const* q) {
   std::string data(oss.str());
   if (write(STDOUT_FILENO, data.c_str(), data.size()) !=
       static_cast<ssize_t>(data.size())) {
-    throw basic_error() << "write query execute failed";
+    throw msg_fmt("write query execute failed");
   }
 }
 
@@ -163,7 +160,7 @@ static void query_quit(char const* q) {
   std::string data(oss.str());
   if (write(STDOUT_FILENO, data.c_str(), data.size()) !=
       static_cast<ssize_t>(data.size()))
-    throw basic_error() << "write query quit failed";
+    throw msg_fmt("write query quit failed");
   exit(EXIT_SUCCESS);
 }
 
@@ -186,7 +183,7 @@ static void query_version(char const* q) {
   std::string data(oss.str());
   if (write(STDOUT_FILENO, data.c_str(), data.size()) !=
       static_cast<ssize_t>(data.size())) {
-    throw basic_error() << "write query version failed";
+    throw msg_fmt("write query version failed");
 
     std::ofstream outfile;
     outfile.open("/tmp/test.txt", std::ios_base::app);
@@ -218,7 +215,7 @@ static int wait(std::string& query) {
     ssize_t ret(read(STDIN_FILENO, buffer, sizeof(buffer)));
     if (ret < 0) {
       char const* msg(strerror(errno));
-      throw basic_error() << "invalid read: " << msg;
+      throw msg_fmt("invalid read: {}", msg);
     }
     if (!ret)
       return -1;
@@ -237,7 +234,7 @@ static int wait(std::string& query) {
   uint32_t id(strtol(query_str, &endptr, 10));
   if (query_str == endptr) {
     responses.pop_front();
-    throw basic_error() << "invalid query";
+    throw msg_fmt("invalid query");
   }
   query.clear();
   query.append(endptr + 1, response.size() - ((endptr + 1) - query_str));
@@ -271,7 +268,7 @@ int main() {
           static_cast<uint32_t>(id) >=
               sizeof(tab_send_query) / sizeof(*tab_send_query) ||
           !tab_send_query[id])
-        throw basic_error() << "reveive bad request id: id=" << id;
+        throw msg_fmt("reveive bad request id: id={}", id);
       (*tab_send_query[id])(query.c_str());
     }
   } catch (std::exception const& e) {
