@@ -256,6 +256,15 @@ debianLinkNagios() {
   fi
 }
 
+createEngineContextFile() {
+  FILE="/etc/centreon-engine/engine-context.json"
+  if [ ! -f "$FILE" ]; then
+    touch "$FILE"
+    chmod 660 "$FILE"
+    chown centreon-engine:centreon-engine "$FILE"
+  fi
+}
+
 # on debian, it is needed to recreate centreon-engine user at each upgrade because it is removed on postrm step on versions < 23.10
 if [ "$1" = "configure" ] ; then
   if [ ! "$(getent passwd centreon-engine)" ]; then
@@ -280,9 +289,7 @@ if [ "$1" = "configure" ] ; then
     /var/lib/centreon-engine \
     /var/log/centreon-engine
   chmod -R g+w \
-    /etc/centreon-engine
-
-  chmod -R 0755 \
+    /etc/centreon-engine \
     /var/log/centreon-engine
 fi
 
@@ -304,9 +311,11 @@ fi
 
 case "$action" in
   "1" | "install")
+    createEngineContextFile
     startCentengine
     ;;
   "2" | "upgrade")
+    createEngineContextFile
     patch_folder_whitelist
     startCentengine
     ;;
