@@ -45,6 +45,7 @@ CREATE TABLE `instances` (
   `version` varchar(16) DEFAULT NULL,
   `deleted` tinyint(1) NOT NULL DEFAULT '0',
   `outdated` tinyint(1) NOT NULL DEFAULT '0',
+  `is_encryption_ready` tinyint(1) NOT NULL DEFAULT '0',
   PRIMARY KEY (`instance_id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
@@ -1533,7 +1534,7 @@ SET FOREIGN_KEY_CHECKS=1;
 -- Agent CEIP
 --
 DROP TABLE IF EXISTS agent_information;
-CREATE TABLE `centreon_storage`.`agent_information` (
+CREATE TABLE agent_information (
   `poller_id` BIGINT(20) NOT NULL,
   `enabled` TINYINT(1) NOT NULL DEFAULT 1,
   `infos` JSON NOT NULL,
