@@ -1,23 +1,45 @@
 #!/usr/bin/python3
 import pymysql.cursors
-from robot.libraries.BuiltIn import BuiltIn
+from robot.libraries.BuiltIn import BuiltIn,RobotNotRunningError
 
 
-BuiltIn().import_resource('db_variables.resource')
-DB_NAME_STORAGE = BuiltIn().get_variable_value("${DBName}")
-DB_NAME_CONF = BuiltIn().get_variable_value("${DBNameConf}")
-DB_USER_ROOT = BuiltIn().get_variable_value("${DBUserRoot}")
-DB_PASS_ROOT = BuiltIn().get_variable_value("${DBPassRoot}")
-DB_USER = BuiltIn().get_variable_value("${DBUser}")
-DB_PASS = BuiltIn().get_variable_value("${DBPass}")
-DB_HOST = BuiltIn().get_variable_value("${DBHost}")
-DB_PORT = BuiltIn().get_variable_value("${DBPort}")
-VAR_ROOT = BuiltIn().get_variable_value("${VarRoot}")
-ETC_ROOT = BuiltIn().get_variable_value("${EtcRoot}")
 
-CONF_DIR = ETC_ROOT + "/centreon-engine"
-ENGINE_HOME = VAR_ROOT + "/lib/centreon-engine"
+def import_robot_resources():
+    global DB_NAME_STORAGE, DB_NAME_CONF, DB_USER_ROOT, DB_PASS_ROOT, DB_USER, DB_PASS, DB_HOST, DB_PORT, VAR_ROOT, ETC_ROOT, CONF_DIR, ENGINE_HOME
+    try:
+        BuiltIn().import_resource('db_variables.resource')
+        DB_NAME_STORAGE = BuiltIn().get_variable_value("${DBName}")
+        DB_NAME_CONF = BuiltIn().get_variable_value("${DBNameConf}")
+        DB_USER_ROOT = BuiltIn().get_variable_value("${DBUserRoot}")
+        DB_PASS_ROOT = BuiltIn().get_variable_value("${DBPassRoot}")
+        DB_USER = BuiltIn().get_variable_value("${DBUser}")
+        DB_PASS = BuiltIn().get_variable_value("${DBPass}")
+        DB_HOST = BuiltIn().get_variable_value("${DBHost}")
+        DB_PORT = BuiltIn().get_variable_value("${DBPort}")
+        VAR_ROOT = BuiltIn().get_variable_value("${VarRoot}")
+        ETC_ROOT = BuiltIn().get_variable_value("${EtcRoot}")
 
+        CONF_DIR = ETC_ROOT + "/centreon-engine"
+        ENGINE_HOME = VAR_ROOT + "/lib/centreon-engine"
+    except RobotNotRunningError:
+        # Handle this case if Robot Framework is not running
+        print("Robot Framework is not running. Skipping resource import.")
+
+DB_NAME_STORAGE = ""
+DB_NAME_CONF = ""
+DB_USER_ROOT = ""
+DB_PASS_ROOT = ""
+DB_USER = ""
+DB_PASS = ""
+DB_HOST = ""
+DB_PORT = ""
+VAR_ROOT = ""
+ETC_ROOT = ""
+
+CONF_DIR = ""
+ENGINE_HOME = ""
+
+import_robot_resources()
 
 class DbConf:
     def __init__(self, engine):
@@ -31,9 +53,8 @@ class DbConf:
         self.commands_count = 50
         self.instances = engine.instances
         self.service_cmd = engine.service_cmd
-        self.hosts_count = len(engine.hosts)
-        self.services_per_host_count = int(
-            len(engine.services)/len(engine.hosts))
+        self.hosts_count = 50
+        self.services_per_host_count = 20
         self.commands_per_poller_count = 50
         self.ctn_clear_db()
         self.engine = engine
@@ -232,7 +253,7 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
                 connection.commit()
                 return (id_ba, sid)
 
-    def ctn_create_ba(self, name: str, typ: str, critical_impact: int, warning_impact: int, dt_policy: str, activate: int = 1):
+    def ctn_create_ba(self, name: str, typ: str, critical_impact: int, warning_impact: int, dt_policy: str, activate:int = 1):
         """
         Create a BA in the centreon database.
 
@@ -269,8 +290,7 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
             else:
                 inherit_dt = 0
             with connection.cursor() as cursor:
-                cursor.execute(
-                    f"INSERT INTO mod_bam (name, state_source, activate,id_reporting_period,level_w,level_c,id_notification_period,notifications_enabled,event_handler_enabled, inherit_kpi_downtimes) VALUES ('{name}',{t},'{activate}',1, {warning_impact}, {critical_impact}, 1,'0', '0','{inherit_dt}')")
+                cursor.execute(f"INSERT INTO mod_bam (name, state_source, activate,id_reporting_period,level_w,level_c,id_notification_period,notifications_enabled,event_handler_enabled, inherit_kpi_downtimes) VALUES ('{name}',{t},'{activate}',1, {warning_impact}, {critical_impact}, 1,'0', '0','{inherit_dt}')")
                 id_ba = cursor.lastrowid
                 sid = self.engine.create_bam_service("ba_{}".format(
                     id_ba), name, "_Module_BAM_1", "centreon-bam-check!{}".format(id_ba))
@@ -308,8 +328,7 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
 
         with connection:
             with connection.cursor() as cursor:
-                cursor.execute(
-                    f"DELETE FROM mod_bam_kpi WHERE host_id={self.host[host]} AND service_id={self.service[svc]} AND id_ba={id_ba}")
+                cursor.execute(f"DELETE FROM mod_bam_kpi WHERE host_id={self.host[host]} AND service_id={self.service[svc]} AND id_ba={id_ba}")
             connection.commit()
 
     def ctn_add_boolean_kpi(self, id_ba: int, expression: str, impact_if: bool, critical_impact: int):
@@ -361,7 +380,7 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
 
             connection.commit()
 
-    def ctn_add_relations_ba_timeperiods(self, id_ba: int, id_time_period: int):
+    def ctn_add_relations_ba_timeperiods(self, id_ba:int, id_time_period:int):
         """
         Add a line in mod_bam_relations_ba_timeperiods table
 
@@ -378,7 +397,6 @@ VALUES (1,'24x7','24_Hours_A_Day,_7_Days_A_Week','00:00-24:00','00:00-24:00','00
 
         with connection:
             with connection.cursor() as cursor:
-                cursor.execute(
-                    f"INSERT INTO mod_bam_relations_ba_timeperiods (ba_id, tp_id) VALUES ({id_ba},{id_time_period})")
+                cursor.execute(f"INSERT INTO mod_bam_relations_ba_timeperiods (ba_id, tp_id) VALUES ({id_ba},{id_time_period})")
 
             connection.commit()
